#!ruby.exe -w
#
#  TOPPERS Configuration Generator
# 
#  Copyright (C) 2019 by FUJI SOFT INCORPORATED All rights reserved.
# 
#  上記著作権者は，以下の(1)〜(4)の条件を満たす場合に限り，本ソフトウェ
#  ア（本ソフトウェアを改変したものを含む．以下同じ）を使用・複製・改
#  変・再配布（以下，利用と呼ぶ）することを無償で許諾する．
#  (1) 本ソフトウェアをソースコードの形で利用する場合には，上記の著作
#      権表示，この利用条件および下記の無保証規定が，そのままの形でソー
#      スコード中に含まれていること．
#  (2) 本ソフトウェアを，ライブラリ形式など，他のソフトウェア開発に使
#      用できる形で再配布する場合には，再配布に伴うドキュメント（利用
#      者マニュアルなど）に，上記の著作権表示，この利用条件および下記
#      の無保証規定を掲載すること．
#  (3) 本ソフトウェアを，機器に組み込むなど，他のソフトウェア開発に使
#      用できない形で再配布する場合には，次のいずれかの条件を満たすこ
#      と．
#    (a) 再配布に伴うドキュメント（利用者マニュアルなど）に，上記の著
#        作権表示，この利用条件および下記の無保証規定を掲載すること．
#    (b) 再配布の形態を，別に定める方法によって，TOPPERSプロジェクトに
#        報告すること．
#  (4) 本ソフトウェアの利用により直接的または間接的に生じるいかなる損
#      害からも，上記著作権者およびTOPPERSプロジェクトを免責すること．
#      また，本ソフトウェアのユーザまたはエンドユーザからのいかなる理
#      由に基づく請求からも，上記著作権者およびTOPPERSプロジェクトを
#      免責すること．
# 
#  本ソフトウェアは，無保証で提供されているものである．上記著作権者お
#  よびTOPPERSプロジェクトは，本ソフトウェアに関して，特定の使用目的
#  に対する適合性も含めて，いかなる保証も行わない．また，本ソフトウェ
#  アの利用により直接的または間接的に生じたいかなる損害に関しても，そ
#  の責任を負わない．

require "pp"
require "yaml"
require "rexml/document.rb"
include REXML
STDOUT.sync = true

begin
  require "gtk3"
rescue LoadError
  puts("Install GTK3")
  puts(" [Windows] https://qiita.com/doublev80/items/6b0f623b2e4aa63c4bb6")
  puts(" [Linux, Mac] $ gem install gtk3")
  exit(1)
end

MAIN_TITLE = "TOPPERS Configuration Generator"
PANGO_FONT = Pango::FontDescription.new("Sans 10")
COLOR_DEFAULT = Gdk::RGBA::new(0, 0, 0, 1.0)
COLOR_EDITED = Gdk::RGBA::new(1.0, 0, 0, 1.0)
ALL_OBJ_LABEL = [:task, :semaphore, :eventflag, :dataqueue, :pridataq, :mutex, :messagebuf, :spin_lock, :mempfix, :cyclic, :alarm]
PROFILES = [:asp3, :fmp3, :hrp3, :hrmp3]

sGladeData = <<-EOS
<?xml version="1.0" encoding="UTF-8"?>
<interface>
  <requires lib="gtk+" version="3.20"/>
  <object class="GtkWindow" id="window_main">
    <property name="can_focus">False</property>
    <property name="resizable">False</property>
    <signal name="delete-event" handler="window_close" swapped="no"/>
    <signal name="destroy" handler="window_destroy" swapped="no"/>
    <child>
      <placeholder/>
    </child>
    <child>
      <object class="GtkFixed">
        <property name="width_request">800</property>
        <property name="height_request">675</property>
        <property name="visible">True</property>
        <property name="can_focus">False</property>
        <child>
          <object class="GtkButton">
            <property name="label" translatable="yes">開く</property>
            <property name="visible">True</property>
            <property name="can_focus">True</property>
            <property name="receives_default">True</property>
            <property name="tooltip_text" translatable="yes">コンフィグ情報を保存したyamlファイルを開く</property>
            <signal name="clicked" handler="button_open_clicked" swapped="no"/>
          </object>
          <packing>
            <property name="x">10</property>
            <property name="y">10</property>
          </packing>
        </child>
        <child>
          <object class="GtkButton">
            <property name="label" translatable="yes">保存</property>
            <property name="visible">True</property>
            <property name="can_focus">True</property>
            <property name="receives_default">True</property>
            <property name="tooltip_text" translatable="yes">コンフィグ情報をyamlファイルへ保存する</property>
            <signal name="clicked" handler="button_save_clicked" swapped="no"/>
          </object>
          <packing>
            <property name="x">73</property>
            <property name="y">10</property>
          </packing>
        </child>
        <child>
          <object class="GtkButton">
            <property name="label" translatable="yes">上書き保存</property>
            <property name="visible">True</property>
            <property name="can_focus">True</property>
            <property name="receives_default">True</property>
            <property name="tooltip_text" translatable="yes">現在開いているyamlファイルへ上書き保存する</property>
            <signal name="clicked" handler="button_overwrite_save_clicked" swapped="no"/>
          </object>
          <packing>
            <property name="x">140</property>
            <property name="y">10</property>
          </packing>
        </child>
        <child>
          <object class="GtkLabel">
            <property name="width_request">60</property>
            <property name="height_request">30</property>
            <property name="visible">True</property>
            <property name="can_focus">False</property>
            <property name="label" translatable="yes">Profile</property>
            <attributes>
              <attribute name="font-desc" value="Sans 10"/>
            </attributes>
          </object>
          <packing>
            <property name="x">255</property>
            <property name="y">10</property>
          </packing>
        </child>
        <child>
          <object class="GtkButtonBox">
            <property name="width_request">80</property>
            <property name="height_request">30</property>
            <property name="visible">True</property>
            <property name="can_focus">False</property>
            <property name="double_buffered">False</property>
            <property name="homogeneous">True</property>
            <property name="layout_style">start</property>
            <child>
              <object class="GtkRadioButton" id="asp3">
                <property name="label" translatable="yes">ASP3</property>
                <property name="visible">True</property>
                <property name="can_focus">True</property>
                <property name="receives_default">False</property>
                <property name="active">True</property>
                <property name="draw_indicator">True</property>
                <signal name="toggled" handler="profile_changed" swapped="no"/>
              </object>
              <packing>
                <property name="expand">True</property>
                <property name="fill">True</property>
                <property name="position">0</property>
              </packing>
            </child>
            <child>
              <object class="GtkRadioButton" id="fmp3">
                <property name="label" translatable="yes">FMP3</property>
                <property name="visible">True</property>
                <property name="can_focus">True</property>
                <property name="receives_default">False</property>
                <property name="draw_indicator">True</property>
                <property name="group">asp3</property>
                <signal name="toggled" handler="profile_changed" swapped="no"/>
              </object>
              <packing>
                <property name="expand">True</property>
                <property name="fill">True</property>
                <property name="position">1</property>
              </packing>
            </child>
            <child>
              <object class="GtkRadioButton" id="hrp3">
                <property name="label" translatable="yes">HRP3</property>
                <property name="visible">True</property>
                <property name="can_focus">True</property>
                <property name="receives_default">False</property>
                <property name="draw_indicator">True</property>
                <property name="group">asp3</property>
                <signal name="toggled" handler="profile_changed" swapped="no"/>
              </object>
              <packing>
                <property name="expand">True</property>
                <property name="fill">True</property>
                <property name="position">2</property>
              </packing>
            </child>
            <child>
              <object class="GtkRadioButton" id="hrmp3">
                <property name="label" translatable="yes">HRMP3</property>
                <property name="visible">True</property>
                <property name="can_focus">True</property>
                <property name="receives_default">False</property>
                <property name="double_buffered">False</property>
                <property name="draw_indicator">True</property>
                <property name="group">asp3</property>
                <signal name="toggled" handler="profile_changed" swapped="no"/>
              </object>
              <packing>
                <property name="expand">True</property>
                <property name="fill">True</property>
                <property name="position">3</property>
              </packing>
            </child>
          </object>
          <packing>
            <property name="x">320</property>
            <property name="y">12</property>
          </packing>
        </child>
        <child>
          <object class="GtkButton">
            <property name="label">表示</property>
            <property name="visible">True</property>
            <property name="can_focus">True</property>
            <property name="receives_default">True</property>
            <property name="margin_right">63</property>
            <signal name="clicked" handler="button_print_clicked" swapped="no"/>
          </object>
          <packing>
            <property name="x">610</property>
            <property name="y">625</property>
          </packing>
        </child>
        <child>
          <object class="GtkButton">
            <property name="label">ファイル出力</property>
            <property name="visible">True</property>
            <property name="can_focus">True</property>
            <property name="receives_default">True</property>
            <signal name="clicked" handler="button_output_clicked" swapped="no"/>
          </object>
          <packing>
            <property name="x">675</property>
            <property name="y">625</property>
          </packing>
        </child>
        <child>
          <object class="GtkNotebook">
            <property name="width_request">780</property>
            <property name="height_request">560</property>
            <property name="visible">True</property>
            <property name="can_focus">True</property>
            <property name="tab_pos">left</property>
            <child>
              <object class="GtkFixed">
                <property name="visible">True</property>
                <property name="can_focus">False</property>
                <child>
                  <object class="GtkButton">
                    <property name="label" translatable="yes">追加</property>
                    <property name="name">task</property>
                    <property name="width_request">58</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <property name="receives_default">True</property>
                    <property name="tooltip_text" translatable="yes">タスクを追加する</property>
                    <signal name="clicked" handler="button_add_clicked" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">10</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkButton" id="task_button_update">
                    <property name="label" translatable="yes">更新</property>
                    <property name="name">task</property>
                    <property name="width_request">58</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <property name="receives_default">True</property>
                    <property name="tooltip_text" translatable="yes">修正した内容で更新する
※更新せずにタスクを変更すると変更内容が破棄される</property>
                    <signal name="clicked" handler="button_update_clicked" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">75</property>
                    <property name="y">10</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkButton">
                    <property name="label" translatable="yes">削除</property>
                    <property name="name">task</property>
                    <property name="width_request">58</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <property name="receives_default">True</property>
                    <property name="tooltip_text" translatable="yes">選択中のタスクを削除する</property>
                    <signal name="clicked" handler="button_delete_clicked" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">140</property>
                    <property name="y">10</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkComboBoxText" id="task_combo_box">
                    <property name="name">task</property>
                    <property name="width_request">190</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">編集するタスクを選択する</property>
                    <signal name="changed" handler="combo_changed" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">50</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">生成するタスクのID番号</property>
                    <property name="label" translatable="yes">タスクID</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">100</property>
                    <property name="height_request">80</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">タスク属性</property>
                    <property name="label" translatable="yes">属性</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">140</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">タスクの拡張情報</property>
                    <property name="label" translatable="yes">拡張情報</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">200</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">タスクのメインルーチンの先頭番地</property>
                    <property name="label" translatable="yes">先頭番地</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">240</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">タスクの起動時優先度</property>
                    <property name="label" translatable="yes">起動時優先度</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">280</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">タスクのスタック領域のサイズ（バイト数）</property>
                    <property name="label" translatable="yes">スタックサイズ</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">320</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">タスクのスタック領域の先頭番地</property>
                    <property name="label" translatable="yes">スタック先頭番地</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">360</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">36</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">タスクのシステムスタック領域のサイズ
（バイト数，保護機能対応カーネルの場合，静的APIにおいては省略可）</property>
                    <property name="label" translatable="yes">システムスタック
サイズ</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">400</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">36</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">タスクのシステムスタック領域の先頭番地
（保護機能対応カーネルの場合，静的APIにおいては省略可）</property>
                    <property name="label" translatable="yes">システムスタック
先頭番地</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">440</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="task_id">
                    <property name="name">task</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkButtonBox">
                    <property name="width_request">115</property>
                    <property name="height_request">55</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="orientation">vertical</property>
                    <property name="homogeneous">True</property>
                    <property name="layout_style">expand</property>
                    <child>
                      <object class="GtkCheckButton" id="task_att_act">
                        <property name="label" translatable="yes">TA_ACT</property>
                        <property name="name">task</property>
                        <property name="width_request">-1</property>
                        <property name="visible">True</property>
                        <property name="can_focus">True</property>
                        <property name="receives_default">False</property>
                        <property name="tooltip_text" translatable="yes">タスクの生成時にタスクを起動する</property>
                        <property name="halign">start</property>
                        <property name="draw_indicator">True</property>
                        <signal name="toggled" handler="param_edited" swapped="no"/>
                      </object>
                      <packing>
                        <property name="expand">True</property>
                        <property name="fill">True</property>
                        <property name="position">0</property>
                      </packing>
                    </child>
                    <child>
                      <object class="GtkCheckButton" id="task_att_noactque">
                        <property name="label" translatable="yes">TA_NOACTQUE</property>
                        <property name="name">task</property>
                        <property name="width_request">-1</property>
                        <property name="visible">True</property>
                        <property name="can_focus">True</property>
                        <property name="receives_default">False</property>
                        <property name="tooltip_text" translatable="yes">タスクに対する起動要求をキューイングしない</property>
                        <property name="halign">start</property>
                        <property name="draw_indicator">True</property>
                        <signal name="toggled" handler="param_edited" swapped="no"/>
                      </object>
                      <packing>
                        <property name="expand">True</property>
                        <property name="fill">True</property>
                        <property name="position">1</property>
                      </packing>
                    </child>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">140</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="task_exinf">
                    <property name="name">task</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">200</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="task_task">
                    <property name="name">task</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">240</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="task_itskpri">
                    <property name="name">task</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">280</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="task_stksz">
                    <property name="name">task</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">320</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="task_stk">
                    <property name="name">task</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">360</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="task_sstksz">
                    <property name="name">task</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">400</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="task_sstk">
                    <property name="name">task</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">440</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">タスクが所属するクラス
（クラス：マルチプロセッサに対応するために用いるカーネルオブジェクトの集合）</property>
                    <property name="label" translatable="yes">クラス</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">タスクが所属する保護ドメイン
（保護ドメイン：保護機能を提供するために用いるカーネルオブジェクトの集合）</property>
                    <property name="label" translatable="yes">保護ドメイン</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">140</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">以下の操作が許可されるドメイン
・act_tsk
・mact_tsk
・can_act
・mig_tsk
・wup_tsk
・can_wup</property>
                    <property name="label" translatable="yes">アクセス許可パターン
通常操作1</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">180</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">以下の操作が許可されるドメイン
・chg_pri
・chg_spr
・rel_wai
・sus_tsk
・rsm_tsk
・ras_ter
・sta_ovr
・stp_ovr</property>
                    <property name="label" translatable="yes">アクセス許可パターン
通常操作2</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">220</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">以下の操作が許可されるドメイン
・del_tsk
・sac_tsk
・ter_tsk</property>
                    <property name="label" translatable="yes">アクセス許可パターン
管理操作</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">260</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">以下の操作が許可されるドメイン
・get_tst
・get_pri
・ref_tsk
・ref_ovr
・prb_mem</property>
                    <property name="label" translatable="yes">アクセス許可パターン
参照操作</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">300</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkComboBoxText" id="task_class">
                    <property name="name">task</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">＜CLS_ALL_PRC1＞
　プロセッサ1が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_ALL_PRC2＞
　プロセッサ2が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_ALL_PRC3＞
　プロセッサ3が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_ALL_PRC4＞
　プロセッサ4が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_PRC1＞
　プロセッサ1が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ1のみ．

＜CLS_PRC2＞
　プロセッサ2が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ2のみ．

＜CLS_PRC3＞
　プロセッサ3が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ3のみ．

＜CLS_PRC4＞
　プロセッサ4が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ4のみ．</property>
                    <property name="active">0</property>
                    <items>
                      <item translatable="yes">CLS_ALL_PRC1</item>
                      <item translatable="yes">CLS_ALL_PRC2</item>
                      <item translatable="yes">CLS_ALL_PRC3</item>
                      <item translatable="yes">CLS_ALL_PRC4</item>
                      <item translatable="yes">CLS_PRC1</item>
                      <item translatable="yes">CLS_PRC2</item>
                      <item translatable="yes">CLS_PRC3</item>
                      <item translatable="yes">CLS_PRC4</item>
                    </items>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="task_domain">
                    <property name="name">task</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">140</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="task_acptn1">
                    <property name="name">task</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">180</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="task_acptn2">
                    <property name="name">task</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">220</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="task_acptn3">
                    <property name="name">task</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">260</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="task_acptn4">
                    <property name="name">task</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">300</property>
                  </packing>
                </child>
              </object>
            </child>
            <child type="tab">
              <object class="GtkLabel">
                <property name="visible">True</property>
                <property name="can_focus">False</property>
                <property name="tooltip_text" translatable="yes">タスクは，プログラムの並行実行の単位で，カーネルが実行を制御する処理単位である．</property>
                <property name="label" translatable="yes">タスク</property>
                <property name="justify">center</property>
              </object>
              <packing>
                <property name="tab_fill">False</property>
              </packing>
            </child>
            <child>
              <object class="GtkFixed">
                <property name="visible">True</property>
                <property name="can_focus">False</property>
                <child>
                  <object class="GtkButton">
                    <property name="label" translatable="yes">追加</property>
                    <property name="name">semaphore</property>
                    <property name="width_request">58</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <property name="receives_default">True</property>
                    <property name="tooltip_text" translatable="yes">セマフォを追加する</property>
                    <signal name="clicked" handler="button_add_clicked" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">10</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkButton" id="semaphore_button_update">
                    <property name="label" translatable="yes">更新</property>
                    <property name="name">semaphore</property>
                    <property name="width_request">58</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <property name="receives_default">True</property>
                    <property name="tooltip_text" translatable="yes">修正した内容で更新する
※更新せずにセマフォを変更すると変更内容が破棄される</property>
                    <signal name="clicked" handler="button_update_clicked" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">75</property>
                    <property name="y">10</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkButton">
                    <property name="label" translatable="yes">削除</property>
                    <property name="name">semaphore</property>
                    <property name="width_request">58</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <property name="receives_default">True</property>
                    <property name="tooltip_text" translatable="yes">選択中のセマフォを削除する</property>
                    <signal name="clicked" handler="button_delete_clicked" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">140</property>
                    <property name="y">10</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkComboBoxText" id="semaphore_combo_box">
                    <property name="name">semaphore</property>
                    <property name="width_request">190</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">編集するセマフォを選択する</property>
                    <signal name="changed" handler="combo_changed" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">50</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">生成するセマフォのID番号</property>
                    <property name="label" translatable="yes">セマフォID</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">セマフォ属性</property>
                    <property name="label" translatable="yes">属性</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">140</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">セマフォの初期資源数</property>
                    <property name="label" translatable="yes">初期資源数</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">180</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">セマフォの最大資源数</property>
                    <property name="label" translatable="yes">最大資源数</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">220</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="semaphore_id">
                    <property name="name">semaphore</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkCheckButton" id="semaphore_att_tpri">
                    <property name="label" translatable="yes">TA_TPRI</property>
                    <property name="name">semaphore</property>
                    <property name="width_request">77</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <property name="receives_default">False</property>
                    <property name="tooltip_text" translatable="yes">待ち行列をタスクの優先度順にする</property>
                    <property name="halign">start</property>
                    <property name="draw_indicator">True</property>
                    <signal name="toggled" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">140</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="semaphore_isemcnt">
                    <property name="name">semaphore</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">180</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="semaphore_maxsem">
                    <property name="name">semaphore</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">220</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">セマフォが所属するクラス
（クラス：マルチプロセッサに対応するために用いるカーネルオブジェクトの集合）</property>
                    <property name="label" translatable="yes">クラス</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">セマフォが所属する保護ドメイン
（保護ドメイン：保護機能を提供するために用いるカーネルオブジェクトの集合）</property>
                    <property name="label" translatable="yes">保護ドメイン</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">140</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">以下の操作が許可されるドメイン
・sig_sem</property>
                    <property name="label" translatable="yes">アクセス許可パターン
通常操作1</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">180</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">以下の操作が許可されるドメイン
・wai_sem
・pol_sem
・twai_sem</property>
                    <property name="label" translatable="yes">アクセス許可パターン
通常操作2</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">220</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">以下の操作が許可されるドメイン
・del_sem
・ini_sem
・sac_sem</property>
                    <property name="label" translatable="yes">アクセス許可パターン
管理操作</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">260</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">以下の操作が許可されるドメイン
・ref_sem</property>
                    <property name="label" translatable="yes">アクセス許可パターン
参照操作</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">300</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkComboBoxText" id="semaphore_class">
                    <property name="name">semaphore</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">＜CLS_ALL_PRC1＞
　プロセッサ1が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_ALL_PRC2＞
　プロセッサ2が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_ALL_PRC3＞
　プロセッサ3が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_ALL_PRC4＞
　プロセッサ4が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_PRC1＞
　プロセッサ1が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ1のみ．

＜CLS_PRC2＞
　プロセッサ2が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ2のみ．

＜CLS_PRC3＞
　プロセッサ3が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ3のみ．

＜CLS_PRC4＞
　プロセッサ4が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ4のみ．</property>
                    <property name="active">0</property>
                    <items>
                      <item translatable="yes">CLS_ALL_PRC1</item>
                      <item translatable="yes">CLS_ALL_PRC2</item>
                      <item translatable="yes">CLS_ALL_PRC3</item>
                      <item translatable="yes">CLS_ALL_PRC4</item>
                      <item translatable="yes">CLS_PRC1</item>
                      <item translatable="yes">CLS_PRC2</item>
                      <item translatable="yes">CLS_PRC3</item>
                      <item translatable="yes">CLS_PRC4</item>
                    </items>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="semaphore_domain">
                    <property name="name">semaphore</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">140</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="semaphore_acptn1">
                    <property name="name">semaphore</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">180</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="semaphore_acptn2">
                    <property name="name">semaphore</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">220</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="semaphore_acptn3">
                    <property name="name">semaphore</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">260</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="semaphore_acptn4">
                    <property name="name">semaphore</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">300</property>
                  </packing>
                </child>
              </object>
              <packing>
                <property name="position">1</property>
              </packing>
            </child>
            <child type="tab">
              <object class="GtkLabel">
                <property name="visible">True</property>
                <property name="can_focus">False</property>
                <property name="tooltip_text" translatable="yes">セマフォは，資源の数を表す0以上の整数値を取るカウンタ（資源数）を介して，排他制御やイベント通知を行うための同期・通信オブジェクトである．</property>
                <property name="label" translatable="yes">セマフォ</property>
                <property name="justify">center</property>
              </object>
              <packing>
                <property name="position">1</property>
                <property name="tab_fill">False</property>
              </packing>
            </child>
            <child>
              <object class="GtkFixed">
                <property name="visible">True</property>
                <property name="can_focus">False</property>
                <child>
                  <object class="GtkButton">
                    <property name="label" translatable="yes">追加</property>
                    <property name="name">eventflag</property>
                    <property name="width_request">58</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <property name="receives_default">True</property>
                    <property name="tooltip_text" translatable="yes">イベントフラグを追加する</property>
                    <signal name="clicked" handler="button_add_clicked" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">10</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkButton" id="eventflag_button_update">
                    <property name="label" translatable="yes">更新</property>
                    <property name="name">eventflag</property>
                    <property name="width_request">58</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <property name="receives_default">True</property>
                    <property name="tooltip_text" translatable="yes">修正した内容で更新する
※更新せずにイベントフラグを変更すると変更内容が破棄される</property>
                    <signal name="clicked" handler="button_update_clicked" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">75</property>
                    <property name="y">10</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkButton">
                    <property name="label" translatable="yes">削除</property>
                    <property name="name">eventflag</property>
                    <property name="width_request">58</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <property name="receives_default">True</property>
                    <property name="tooltip_text" translatable="yes">選択中のイベントフラグを削除する</property>
                    <signal name="clicked" handler="button_delete_clicked" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">140</property>
                    <property name="y">10</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkComboBoxText" id="eventflag_combo_box">
                    <property name="name">eventflag</property>
                    <property name="width_request">190</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">編集するイベントフラグを選択する</property>
                    <signal name="changed" handler="combo_changed" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">50</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">生成するイベントフラグのID番号</property>
                    <property name="label" translatable="yes">イベントフラグID</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">100</property>
                    <property name="height_request">80</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">イベントフラグ属性</property>
                    <property name="label" translatable="yes">属性</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">140</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">イベントフラグの初期ビットパターン</property>
                    <property name="label" translatable="yes">初期ビットパターン</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">225</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="eventflag_id">
                    <property name="name">eventflag</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkButtonBox">
                    <property name="width_request">115</property>
                    <property name="height_request">80</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="orientation">vertical</property>
                    <property name="homogeneous">True</property>
                    <property name="layout_style">expand</property>
                    <child>
                      <object class="GtkCheckButton" id="eventflag_att_tpri">
                        <property name="label" translatable="yes">TA_TPRI</property>
                        <property name="name">eventflag</property>
                        <property name="width_request">-1</property>
                        <property name="visible">True</property>
                        <property name="can_focus">True</property>
                        <property name="receives_default">False</property>
                        <property name="tooltip_text" translatable="yes">待ち行列をタスクの優先度順にする</property>
                        <property name="halign">start</property>
                        <property name="draw_indicator">True</property>
                        <signal name="toggled" handler="param_edited" swapped="no"/>
                      </object>
                      <packing>
                        <property name="expand">True</property>
                        <property name="fill">True</property>
                        <property name="position">0</property>
                      </packing>
                    </child>
                    <child>
                      <object class="GtkCheckButton" id="eventflag_att_wmul">
                        <property name="label" translatable="yes">TA_WMUL</property>
                        <property name="name">eventflag</property>
                        <property name="width_request">-1</property>
                        <property name="visible">True</property>
                        <property name="can_focus">True</property>
                        <property name="receives_default">False</property>
                        <property name="tooltip_text" translatable="yes">複数のタスクが待つのを許す</property>
                        <property name="halign">start</property>
                        <property name="draw_indicator">True</property>
                        <signal name="toggled" handler="param_edited" swapped="no"/>
                      </object>
                      <packing>
                        <property name="expand">True</property>
                        <property name="fill">True</property>
                        <property name="position">1</property>
                      </packing>
                    </child>
                    <child>
                      <object class="GtkCheckButton" id="eventflag_att_clr">
                        <property name="label" translatable="yes">TA_CLR</property>
                        <property name="name">eventflag</property>
                        <property name="width_request">-1</property>
                        <property name="visible">True</property>
                        <property name="can_focus">True</property>
                        <property name="receives_default">False</property>
                        <property name="tooltip_text" translatable="yes">タスクの待ち解除時にイベントフラグをクリアする</property>
                        <property name="halign">start</property>
                        <property name="draw_indicator">True</property>
                        <signal name="toggled" handler="param_edited" swapped="no"/>
                      </object>
                      <packing>
                        <property name="expand">True</property>
                        <property name="fill">True</property>
                        <property name="position">2</property>
                      </packing>
                    </child>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">140</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="eventflag_iflgptn">
                    <property name="name">eventflag</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">225</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">イベントフラグが所属するクラス
（クラス：マルチプロセッサに対応するために用いるカーネルオブジェクトの集合）</property>
                    <property name="label" translatable="yes">クラス</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">イベントフラグが所属する保護ドメイン
（保護ドメイン：保護機能を提供するために用いるカーネルオブジェクトの集合）</property>
                    <property name="label" translatable="yes">保護ドメイン</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">140</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">以下の操作が許可されるドメイン
・set_flg
・clr_flg</property>
                    <property name="label" translatable="yes">アクセス許可パターン
通常操作1</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">180</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">以下の操作が許可されるドメイン
・wai_flg
・pol_flg
・twai_flg</property>
                    <property name="label" translatable="yes">アクセス許可パターン
通常操作2</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">220</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">以下の操作が許可されるドメイン
・del_flg
・ini_flg
・sac_flg</property>
                    <property name="label" translatable="yes">アクセス許可パターン
管理操作</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">260</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">以下の操作が許可されるドメイン
・ref_flg</property>
                    <property name="label" translatable="yes">アクセス許可パターン
参照操作</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">300</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkComboBoxText" id="eventflag_class">
                    <property name="name">eventflag</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">＜CLS_ALL_PRC1＞
　プロセッサ1が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_ALL_PRC2＞
　プロセッサ2が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_ALL_PRC3＞
　プロセッサ3が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_ALL_PRC4＞
　プロセッサ4が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_PRC1＞
　プロセッサ1が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ1のみ．

＜CLS_PRC2＞
　プロセッサ2が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ2のみ．

＜CLS_PRC3＞
　プロセッサ3が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ3のみ．

＜CLS_PRC4＞
　プロセッサ4が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ4のみ．</property>
                    <property name="active">0</property>
                    <items>
                      <item translatable="yes">CLS_ALL_PRC1</item>
                      <item translatable="yes">CLS_ALL_PRC2</item>
                      <item translatable="yes">CLS_ALL_PRC3</item>
                      <item translatable="yes">CLS_ALL_PRC4</item>
                      <item translatable="yes">CLS_PRC1</item>
                      <item translatable="yes">CLS_PRC2</item>
                      <item translatable="yes">CLS_PRC3</item>
                      <item translatable="yes">CLS_PRC4</item>
                    </items>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="eventflag_domain">
                    <property name="name">eventflag</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">140</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="eventflag_acptn1">
                    <property name="name">eventflag</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">180</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="eventflag_acptn2">
                    <property name="name">eventflag</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">220</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="eventflag_acptn3">
                    <property name="name">eventflag</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">260</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="eventflag_acptn4">
                    <property name="name">eventflag</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">300</property>
                  </packing>
                </child>
              </object>
              <packing>
                <property name="position">2</property>
              </packing>
            </child>
            <child type="tab">
              <object class="GtkLabel">
                <property name="visible">True</property>
                <property name="can_focus">False</property>
                <property name="tooltip_text" translatable="yes">イベントフラグは，イベントの発生の有無を表すビットの集合（ビットパターン）を介して，イベント通知を行うための同期・通信オブジェクトである．</property>
                <property name="label" translatable="yes">イベントフラグ</property>
                <property name="justify">center</property>
              </object>
              <packing>
                <property name="position">2</property>
                <property name="tab_fill">False</property>
              </packing>
            </child>
            <child>
              <object class="GtkFixed">
                <property name="visible">True</property>
                <property name="can_focus">False</property>
                <child>
                  <object class="GtkButton">
                    <property name="label" translatable="yes">追加</property>
                    <property name="name">dataqueue</property>
                    <property name="width_request">58</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <property name="receives_default">True</property>
                    <property name="tooltip_text" translatable="yes">データキューを追加する</property>
                    <signal name="clicked" handler="button_add_clicked" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">10</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkButton" id="dataqueue_button_update">
                    <property name="label" translatable="yes">更新</property>
                    <property name="name">dataqueue</property>
                    <property name="width_request">58</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <property name="receives_default">True</property>
                    <property name="tooltip_text" translatable="yes">修正した内容で更新する
※更新せずにデータキューを変更すると変更内容が破棄される</property>
                    <signal name="clicked" handler="button_update_clicked" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">75</property>
                    <property name="y">10</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkButton">
                    <property name="label" translatable="yes">削除</property>
                    <property name="name">dataqueue</property>
                    <property name="width_request">58</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <property name="receives_default">True</property>
                    <property name="tooltip_text" translatable="yes">選択中のデータキューを削除する</property>
                    <signal name="clicked" handler="button_delete_clicked" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">140</property>
                    <property name="y">10</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkComboBoxText" id="dataqueue_combo_box">
                    <property name="name">dataqueue</property>
                    <property name="width_request">190</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">編集するデータキューを選択する</property>
                    <signal name="changed" handler="combo_changed" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">50</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">生成するデータキューのID番号</property>
                    <property name="label" translatable="yes">データキューID</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">データキュー属性</property>
                    <property name="label" translatable="yes">属性</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">140</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">データキュー管理領域に格納できるデータ数</property>
                    <property name="label" translatable="yes">データ数</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">180</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">データキュー管理領域の先頭番地</property>
                    <property name="label" translatable="yes">先頭番地</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">220</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="dataqueue_id">
                    <property name="name">dataqueue</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkCheckButton" id="dataqueue_att_tpri">
                    <property name="label" translatable="yes">TA_TPRI</property>
                    <property name="name">dataqueue</property>
                    <property name="width_request">77</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <property name="receives_default">False</property>
                    <property name="tooltip_text" translatable="yes">送信待ち行列をタスクの優先度順にする</property>
                    <property name="halign">start</property>
                    <property name="draw_indicator">True</property>
                    <signal name="toggled" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">140</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="dataqueue_dtqcnt">
                    <property name="name">dataqueue</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">180</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="dataqueue_dtqmb">
                    <property name="name">dataqueue</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">220</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">データキューが所属するクラス
（クラス：マルチプロセッサに対応するために用いるカーネルオブジェクトの集合）</property>
                    <property name="label" translatable="yes">クラス</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">データキューが所属する保護ドメイン
（保護ドメイン：保護機能を提供するために用いるカーネルオブジェクトの集合）</property>
                    <property name="label" translatable="yes">保護ドメイン</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">140</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">以下の操作が許可されるドメイン
・snd_dtq
・psnd_dtq
・tsnd_dtq
・fsnd_dtq</property>
                    <property name="label" translatable="yes">アクセス許可パターン
通常操作1</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">180</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">以下の操作が許可されるドメイン
・rcv_dtq
・prcv_dtq
・trcv_dtq</property>
                    <property name="label" translatable="yes">アクセス許可パターン
通常操作2</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">220</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">以下の操作が許可されるドメイン
・del_dtq
・ini_dtq
・sac_dtq</property>
                    <property name="label" translatable="yes">アクセス許可パターン
管理操作</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">260</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">以下の操作が許可されるドメイン
・ref_dtq</property>
                    <property name="label" translatable="yes">アクセス許可パターン
参照操作</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">300</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkComboBoxText" id="dataqueue_class">
                    <property name="name">dataqueue</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">＜CLS_ALL_PRC1＞
　プロセッサ1が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_ALL_PRC2＞
　プロセッサ2が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_ALL_PRC3＞
　プロセッサ3が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_ALL_PRC4＞
　プロセッサ4が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_PRC1＞
　プロセッサ1が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ1のみ．

＜CLS_PRC2＞
　プロセッサ2が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ2のみ．

＜CLS_PRC3＞
　プロセッサ3が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ3のみ．

＜CLS_PRC4＞
　プロセッサ4が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ4のみ．</property>
                    <property name="active">0</property>
                    <items>
                      <item translatable="yes">CLS_ALL_PRC1</item>
                      <item translatable="yes">CLS_ALL_PRC2</item>
                      <item translatable="yes">CLS_ALL_PRC3</item>
                      <item translatable="yes">CLS_ALL_PRC4</item>
                      <item translatable="yes">CLS_PRC1</item>
                      <item translatable="yes">CLS_PRC2</item>
                      <item translatable="yes">CLS_PRC3</item>
                      <item translatable="yes">CLS_PRC4</item>
                    </items>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="dataqueue_domain">
                    <property name="name">dataqueue</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">140</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="dataqueue_acptn1">
                    <property name="name">dataqueue</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">180</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="dataqueue_acptn2">
                    <property name="name">dataqueue</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">220</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="dataqueue_acptn3">
                    <property name="name">dataqueue</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">260</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="dataqueue_acptn4">
                    <property name="name">dataqueue</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">300</property>
                  </packing>
                </child>
              </object>
              <packing>
                <property name="position">3</property>
              </packing>
            </child>
            <child type="tab">
              <object class="GtkLabel">
                <property name="visible">True</property>
                <property name="can_focus">False</property>
                <property name="tooltip_text" translatable="yes">データキューは，1ワードのデータをメッセージとして，FIFO順で送受信するための同期・通信オブジェクトである．</property>
                <property name="label" translatable="yes">データキュー</property>
                <property name="justify">center</property>
              </object>
              <packing>
                <property name="position">3</property>
                <property name="tab_fill">False</property>
              </packing>
            </child>
            <child>
              <object class="GtkFixed">
                <property name="visible">True</property>
                <property name="can_focus">False</property>
                <child>
                  <object class="GtkButton">
                    <property name="label" translatable="yes">追加</property>
                    <property name="name">pridataq</property>
                    <property name="width_request">58</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <property name="receives_default">True</property>
                    <property name="tooltip_text" translatable="yes">優先度データキューを追加する</property>
                    <signal name="clicked" handler="button_add_clicked" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">10</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkButton" id="pridataq_button_update">
                    <property name="label" translatable="yes">更新</property>
                    <property name="name">pridataq</property>
                    <property name="width_request">58</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <property name="receives_default">True</property>
                    <property name="tooltip_text" translatable="yes">修正した内容で更新する
※更新せずに優先度データキューを変更すると変更内容が破棄される</property>
                    <signal name="clicked" handler="button_update_clicked" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">75</property>
                    <property name="y">10</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkButton">
                    <property name="label" translatable="yes">削除</property>
                    <property name="name">pridataq</property>
                    <property name="width_request">58</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <property name="receives_default">True</property>
                    <property name="tooltip_text" translatable="yes">選択中の優先度データキューを削除する</property>
                    <signal name="clicked" handler="button_delete_clicked" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">140</property>
                    <property name="y">10</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkComboBoxText" id="pridataq_combo_box">
                    <property name="name">pridataq</property>
                    <property name="width_request">190</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">編集する優先度データキューを選択する</property>
                    <signal name="changed" handler="combo_changed" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">50</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">生成する優先度データキューのID番号</property>
                    <property name="label" translatable="yes">優先度データキューID</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">優先度データキュー属性</property>
                    <property name="label" translatable="yes">属性</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">140</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">優先度データキュー管理領域に格納できるデータ数</property>
                    <property name="label" translatable="yes">データ数</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">180</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">優先度データキューに送信できるデータ優先度の最大値</property>
                    <property name="label" translatable="yes">優先度の最大値</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">220</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">優先度データキュー管理領域の先頭番地</property>
                    <property name="label" translatable="yes">先頭番地</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">260</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="pridataq_id">
                    <property name="name">pridataq</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkCheckButton" id="pridataq_att_tpri">
                    <property name="label" translatable="yes">TA_TPRI</property>
                    <property name="name">pridataq</property>
                    <property name="width_request">77</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <property name="receives_default">False</property>
                    <property name="tooltip_text" translatable="yes">送信待ち行列をタスクの優先度順にする</property>
                    <property name="halign">start</property>
                    <property name="draw_indicator">True</property>
                    <signal name="toggled" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">140</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="pridataq_dtqcnt">
                    <property name="name">pridataq</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">180</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="pridataq_maxdpri">
                    <property name="name">pridataq</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">220</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="pridataq_dtqmb">
                    <property name="name">pridataq</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">260</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">優先度データキューが所属するクラス
（クラス：マルチプロセッサに対応するために用いるカーネルオブジェクトの集合）</property>
                    <property name="label" translatable="yes">クラス</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">優先度データキューが所属する保護ドメイン
（保護ドメイン：保護機能を提供するために用いるカーネルオブジェクトの集合）</property>
                    <property name="label" translatable="yes">保護ドメイン</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">140</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">以下の操作が許可されるドメイン
・snd_pdq
・psnd_pdq
・tsnd_pdq</property>
                    <property name="label" translatable="yes">アクセス許可パターン
通常操作1</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">180</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">以下の操作が許可されるドメイン
・rcv_pdq
・prcv_pdq
・trcv_pdq</property>
                    <property name="label" translatable="yes">アクセス許可パターン
通常操作2</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">220</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">以下の操作が許可されるドメイン
・del_pdq
・ini_pdq
・sac_pdq</property>
                    <property name="label" translatable="yes">アクセス許可パターン
管理操作</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">260</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">以下の操作が許可されるドメイン
・ref_pdq</property>
                    <property name="label" translatable="yes">アクセス許可パターン
参照操作</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">300</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkComboBoxText" id="pridataq_class">
                    <property name="name">pridataq</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">＜CLS_ALL_PRC1＞
　プロセッサ1が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_ALL_PRC2＞
　プロセッサ2が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_ALL_PRC3＞
　プロセッサ3が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_ALL_PRC4＞
　プロセッサ4が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_PRC1＞
　プロセッサ1が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ1のみ．

＜CLS_PRC2＞
　プロセッサ2が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ2のみ．

＜CLS_PRC3＞
　プロセッサ3が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ3のみ．

＜CLS_PRC4＞
　プロセッサ4が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ4のみ．</property>
                    <property name="active">0</property>
                    <items>
                      <item translatable="yes">CLS_ALL_PRC1</item>
                      <item translatable="yes">CLS_ALL_PRC2</item>
                      <item translatable="yes">CLS_ALL_PRC3</item>
                      <item translatable="yes">CLS_ALL_PRC4</item>
                      <item translatable="yes">CLS_PRC1</item>
                      <item translatable="yes">CLS_PRC2</item>
                      <item translatable="yes">CLS_PRC3</item>
                      <item translatable="yes">CLS_PRC4</item>
                    </items>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="pridataq_domain">
                    <property name="name">pridataq</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">140</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="pridataq_acptn1">
                    <property name="name">pridataq</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">180</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="pridataq_acptn2">
                    <property name="name">pridataq</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">220</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="pridataq_acptn3">
                    <property name="name">pridataq</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">260</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="pridataq_acptn4">
                    <property name="name">pridataq</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">300</property>
                  </packing>
                </child>
              </object>
              <packing>
                <property name="position">4</property>
              </packing>
            </child>
            <child type="tab">
              <object class="GtkLabel">
                <property name="visible">True</property>
                <property name="can_focus">False</property>
                <property name="tooltip_text" translatable="yes">優先度データキューは，1ワードのデータをメッセージとして，データの優先度順で送受信するための同期・通信オブジェクトである．</property>
                <property name="label" translatable="yes">優先度データキュー</property>
                <property name="justify">center</property>
              </object>
              <packing>
                <property name="position">4</property>
                <property name="tab_fill">False</property>
              </packing>
            </child>
            <child>
              <object class="GtkFixed">
                <property name="visible">True</property>
                <property name="can_focus">False</property>
                <child>
                  <object class="GtkButton">
                    <property name="label" translatable="yes">追加</property>
                    <property name="name">mutex</property>
                    <property name="width_request">58</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <property name="receives_default">True</property>
                    <property name="tooltip_text" translatable="yes">ミューテックスを追加する</property>
                    <signal name="clicked" handler="button_add_clicked" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">10</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkButton" id="mutex_button_update">
                    <property name="label" translatable="yes">更新</property>
                    <property name="name">mutex</property>
                    <property name="width_request">58</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <property name="receives_default">True</property>
                    <property name="tooltip_text" translatable="yes">修正した内容で更新する
※更新せずにミューテックスを変更すると変更内容が破棄される</property>
                    <signal name="clicked" handler="button_update_clicked" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">75</property>
                    <property name="y">10</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkButton">
                    <property name="label" translatable="yes">削除</property>
                    <property name="name">mutex</property>
                    <property name="width_request">58</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <property name="receives_default">True</property>
                    <property name="tooltip_text" translatable="yes">選択中のミューテックスを削除する</property>
                    <signal name="clicked" handler="button_delete_clicked" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">140</property>
                    <property name="y">10</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkComboBoxText" id="mutex_combo_box">
                    <property name="name">mutex</property>
                    <property name="width_request">190</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">編集するミューテックスを選択する</property>
                    <signal name="changed" handler="combo_changed" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">50</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">生成するミューテックスのID番号</property>
                    <property name="label" translatable="yes">ミューテックスID</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">100</property>
                    <property name="height_request">55</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">ミューテックス属性</property>
                    <property name="label" translatable="yes">属性</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">140</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">ミューテックスの上限優先度</property>
                    <property name="label" translatable="yes">上限優先度</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">200</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="mutex_id">
                    <property name="name">mutex</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkButtonBox">
                    <property name="width_request">115</property>
                    <property name="height_request">55</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="orientation">vertical</property>
                    <property name="homogeneous">True</property>
                    <property name="layout_style">expand</property>
                    <child>
                      <object class="GtkCheckButton" id="mutex_att_tpri">
                        <property name="label" translatable="yes">TA_TPRI</property>
                        <property name="name">mutex</property>
                        <property name="width_request">-1</property>
                        <property name="visible">True</property>
                        <property name="can_focus">True</property>
                        <property name="receives_default">False</property>
                        <property name="tooltip_text" translatable="yes">待ち行列をタスクの優先度順にする</property>
                        <property name="halign">start</property>
                        <property name="draw_indicator">True</property>
                        <signal name="toggled" handler="param_edited" swapped="no"/>
                      </object>
                      <packing>
                        <property name="expand">True</property>
                        <property name="fill">True</property>
                        <property name="position">0</property>
                      </packing>
                    </child>
                    <child>
                      <object class="GtkCheckButton" id="mutex_att_ceiling">
                        <property name="label" translatable="yes">TA_CEILING</property>
                        <property name="name">mutex</property>
                        <property name="width_request">-1</property>
                        <property name="visible">True</property>
                        <property name="can_focus">True</property>
                        <property name="receives_default">False</property>
                        <property name="tooltip_text" translatable="yes">優先度上限ミューテックスとする．待ち行列をタスクの優先度順にする</property>
                        <property name="halign">start</property>
                        <property name="draw_indicator">True</property>
                        <signal name="toggled" handler="param_edited" swapped="no"/>
                      </object>
                      <packing>
                        <property name="expand">True</property>
                        <property name="fill">True</property>
                        <property name="position">1</property>
                      </packing>
                    </child>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">140</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="mutex_ceilpri">
                    <property name="name">mutex</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">200</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">ミューテックスが所属するクラス
（クラス：マルチプロセッサに対応するために用いるカーネルオブジェクトの集合）</property>
                    <property name="label" translatable="yes">クラス</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">ミューテックスが所属する保護ドメイン
（保護ドメイン：保護機能を提供するために用いるカーネルオブジェクトの集合）</property>
                    <property name="label" translatable="yes">保護ドメイン</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">140</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">以下の操作が許可されるドメイン
・loc_mtx
・ploc_mtx
・tloc_mtx
・unl_mtx</property>
                    <property name="label" translatable="yes">アクセス許可パターン
通常操作1</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">180</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">許可される操作なし</property>
                    <property name="label" translatable="yes">アクセス許可パターン
通常操作2</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">220</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">以下の操作が許可されるドメイン
・del_mtx
・ini_mtx
・sac_mtx</property>
                    <property name="label" translatable="yes">アクセス許可パターン
管理操作</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">260</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">以下の操作が許可されるドメイン
・ref_mtx</property>
                    <property name="label" translatable="yes">アクセス許可パターン
参照操作</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">300</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkComboBoxText" id="mutex_class">
                    <property name="name">mutex</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">＜CLS_ALL_PRC1＞
　プロセッサ1が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_ALL_PRC2＞
　プロセッサ2が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_ALL_PRC3＞
　プロセッサ3が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_ALL_PRC4＞
　プロセッサ4が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_PRC1＞
　プロセッサ1が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ1のみ．

＜CLS_PRC2＞
　プロセッサ2が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ2のみ．

＜CLS_PRC3＞
　プロセッサ3が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ3のみ．

＜CLS_PRC4＞
　プロセッサ4が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ4のみ．</property>
                    <property name="active">0</property>
                    <items>
                      <item translatable="yes">CLS_ALL_PRC1</item>
                      <item translatable="yes">CLS_ALL_PRC2</item>
                      <item translatable="yes">CLS_ALL_PRC3</item>
                      <item translatable="yes">CLS_ALL_PRC4</item>
                      <item translatable="yes">CLS_PRC1</item>
                      <item translatable="yes">CLS_PRC2</item>
                      <item translatable="yes">CLS_PRC3</item>
                      <item translatable="yes">CLS_PRC4</item>
                    </items>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="mutex_domain">
                    <property name="name">mutex</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">140</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="mutex_acptn1">
                    <property name="name">mutex</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">180</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="mutex_acptn2">
                    <property name="name">mutex</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">220</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="mutex_acptn3">
                    <property name="name">mutex</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">260</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="mutex_acptn4">
                    <property name="name">mutex</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">300</property>
                  </packing>
                </child>
              </object>
              <packing>
                <property name="position">5</property>
              </packing>
            </child>
            <child type="tab">
              <object class="GtkLabel">
                <property name="visible">True</property>
                <property name="can_focus">False</property>
                <property name="tooltip_text" translatable="yes">ミューテックスは，タスク間の排他制御を行うための同期・通信オブジェクトである．</property>
                <property name="label" translatable="yes">ミューテックス</property>
              </object>
              <packing>
                <property name="position">5</property>
                <property name="tab_fill">False</property>
              </packing>
            </child>
            <child>
              <object class="GtkFixed" id="fixed_messagebuf">
                <property name="visible">True</property>
                <property name="can_focus">False</property>
                <child>
                  <object class="GtkButton">
                    <property name="label" translatable="yes">追加</property>
                    <property name="name">messagebuf</property>
                    <property name="width_request">58</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <property name="receives_default">True</property>
                    <property name="tooltip_text" translatable="yes">メッセージバッファを追加する</property>
                    <signal name="clicked" handler="button_add_clicked" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">10</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkButton" id="messagebuf_button_update">
                    <property name="label" translatable="yes">更新</property>
                    <property name="name">messagebuf</property>
                    <property name="width_request">58</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <property name="receives_default">True</property>
                    <property name="tooltip_text" translatable="yes">修正した内容で更新する
※更新せずにメッセージバッファを変更すると変更内容が破棄される</property>
                    <signal name="clicked" handler="button_update_clicked" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">75</property>
                    <property name="y">10</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkButton">
                    <property name="label" translatable="yes">削除</property>
                    <property name="name">messagebuf</property>
                    <property name="width_request">58</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <property name="receives_default">True</property>
                    <property name="tooltip_text" translatable="yes">選択中のメッセージバッファを削除する</property>
                    <signal name="clicked" handler="button_delete_clicked" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">140</property>
                    <property name="y">10</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkComboBoxText" id="messagebuf_combo_box">
                    <property name="name">messagebuf</property>
                    <property name="width_request">190</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">編集するメッセージバッファを選択する</property>
                    <signal name="changed" handler="combo_changed" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">50</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">生成するメッセージバッファのID番号</property>
                    <property name="label" translatable="yes">メッセージバッファID</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">メッセージバッファの最大メッセージサイズ（バイト数）</property>
                    <property name="label" translatable="yes">最大メッセージサイズ</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">140</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">メッセージバッファ管理領域のサイズ（バイト数）</property>
                    <property name="label" translatable="yes">管理領域のサイズ</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">180</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">メッセージバッファ管理領域の先頭番地</property>
                    <property name="label" translatable="yes">先頭番地</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">220</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="messagebuf_id">
                    <property name="name">messagebuf</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="messagebuf_maxmsz">
                    <property name="name">messagebuf</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">140</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="messagebuf_mbfsz">
                    <property name="name">messagebuf</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">180</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="messagebuf_mbfmb">
                    <property name="name">messagebuf</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">220</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">メッセージバッファが所属するクラス
（クラス：マルチプロセッサに対応するために用いるカーネルオブジェクトの集合）</property>
                    <property name="label" translatable="yes">クラス</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">メッセージバッファが所属する保護ドメイン
（保護ドメイン：保護機能を提供するために用いるカーネルオブジェクトの集合）</property>
                    <property name="label" translatable="yes">保護ドメイン</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">140</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">以下の操作が許可されるドメイン
・snd_mbf
・psnd_mbf
・tsnd_mbf</property>
                    <property name="label" translatable="yes">アクセス許可パターン
通常操作1</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">180</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">以下の操作が許可されるドメイン
・rcv_mbf
・prcv_mbf
・trcv_mbf</property>
                    <property name="label" translatable="yes">アクセス許可パターン
通常操作2</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">220</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">以下の操作が許可されるドメイン
・del_mbf
・ini_mbf
・sac_mbf</property>
                    <property name="label" translatable="yes">アクセス許可パターン
管理操作</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">260</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">以下の操作が許可されるドメイン
・ref_mbf</property>
                    <property name="label" translatable="yes">アクセス許可パターン
参照操作</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">300</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkComboBoxText" id="messagebuf_class">
                    <property name="name">messagebuf</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">＜CLS_ALL_PRC1＞
　プロセッサ1が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_ALL_PRC2＞
　プロセッサ2が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_ALL_PRC3＞
　プロセッサ3が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_ALL_PRC4＞
　プロセッサ4が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_PRC1＞
　プロセッサ1が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ1のみ．

＜CLS_PRC2＞
　プロセッサ2が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ2のみ．

＜CLS_PRC3＞
　プロセッサ3が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ3のみ．

＜CLS_PRC4＞
　プロセッサ4が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ4のみ．</property>
                    <property name="active">0</property>
                    <items>
                      <item translatable="yes">CLS_ALL_PRC1</item>
                      <item translatable="yes">CLS_ALL_PRC2</item>
                      <item translatable="yes">CLS_ALL_PRC3</item>
                      <item translatable="yes">CLS_ALL_PRC4</item>
                      <item translatable="yes">CLS_PRC1</item>
                      <item translatable="yes">CLS_PRC2</item>
                      <item translatable="yes">CLS_PRC3</item>
                      <item translatable="yes">CLS_PRC4</item>
                    </items>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="messagebuf_domain">
                    <property name="name">messagebuf</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">140</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="messagebuf_acptn1">
                    <property name="name">messagebuf</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">180</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="messagebuf_acptn2">
                    <property name="name">messagebuf</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">220</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="messagebuf_acptn3">
                    <property name="name">messagebuf</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">260</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="messagebuf_acptn4">
                    <property name="name">messagebuf</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">300</property>
                  </packing>
                </child>
              </object>
              <packing>
                <property name="position">6</property>
              </packing>
            </child>
            <child type="tab">
              <object class="GtkLabel" id="label_messagebuf">
                <property name="visible">True</property>
                <property name="can_focus">False</property>
                <property name="tooltip_text" translatable="yes">メッセージバッファは，指定したサイズのバイト列をメッセージとして，FIFO順で送受信するための同期・通信オブジェクトである．</property>
                <property name="label" translatable="yes">メッセージバッファ</property>
                <property name="justify">center</property>
              </object>
              <packing>
                <property name="position">6</property>
                <property name="tab_fill">False</property>
              </packing>
            </child>
            <child>
              <object class="GtkFixed" id="fixed_spin_lock">
                <property name="visible">True</property>
                <property name="can_focus">False</property>
                <child>
                  <object class="GtkButton">
                    <property name="label" translatable="yes">追加</property>
                    <property name="name">spin_lock</property>
                    <property name="width_request">58</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <property name="receives_default">True</property>
                    <property name="tooltip_text" translatable="yes">スピンロックを追加する</property>
                    <signal name="clicked" handler="button_add_clicked" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">10</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkButton" id="spin_lock_button_update">
                    <property name="label" translatable="yes">更新</property>
                    <property name="name">spin_lock</property>
                    <property name="width_request">58</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <property name="receives_default">True</property>
                    <property name="tooltip_text" translatable="yes">修正した内容で更新する
※更新せずにスピンロックを変更すると変更内容が破棄される</property>
                    <signal name="clicked" handler="button_update_clicked" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">75</property>
                    <property name="y">10</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkButton">
                    <property name="label" translatable="yes">削除</property>
                    <property name="name">spin_lock</property>
                    <property name="width_request">58</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <property name="receives_default">True</property>
                    <property name="tooltip_text" translatable="yes">選択中のスピンロックを削除する</property>
                    <signal name="clicked" handler="button_delete_clicked" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">140</property>
                    <property name="y">10</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkComboBoxText" id="spin_lock_combo_box">
                    <property name="name">spin_lock</property>
                    <property name="width_request">190</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">編集するスピンロックを選択する</property>
                    <signal name="changed" handler="combo_changed" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">50</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">生成するスピンロックのID番号</property>
                    <property name="label" translatable="yes">スピンロックID</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">スピンロック属性</property>
                    <property name="label" translatable="yes">属性</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">140</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="spin_lock_id">
                    <property name="name">spin_lock</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkCheckButton" id="spin_lock_att_native">
                    <property name="label" translatable="yes">TA_NATIVE</property>
                    <property name="name">spin_lock</property>
                    <property name="width_request">77</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <property name="receives_default">False</property>
                    <property name="tooltip_text" translatable="yes">エミュレーションによって実現してはならない</property>
                    <property name="halign">start</property>
                    <property name="draw_indicator">True</property>
                    <signal name="toggled" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">140</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">スピンロックが所属するクラス
（クラス：マルチプロセッサに対応するために用いるカーネルオブジェクトの集合）</property>
                    <property name="label" translatable="yes">クラス</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">スピンロックが所属する保護ドメイン
（保護ドメイン：保護機能を提供するために用いるカーネルオブジェクトの集合）</property>
                    <property name="label" translatable="yes">保護ドメイン</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">140</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">以下の操作が許可されるドメイン
・loc_spn
・try_spn
・unl_spn</property>
                    <property name="label" translatable="yes">アクセス許可パターン
通常操作1</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">180</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">許可される操作なし</property>
                    <property name="label" translatable="yes">アクセス許可パターン
通常操作2</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">220</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">以下の操作が許可されるドメイン
・del_spn
・sac_spn</property>
                    <property name="label" translatable="yes">アクセス許可パターン
管理操作</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">260</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">以下の操作が許可されるドメイン
・ref_spn</property>
                    <property name="label" translatable="yes">アクセス許可パターン
参照操作</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">300</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkComboBoxText" id="spin_lock_class">
                    <property name="name">spin_lock</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">＜CLS_ALL_PRC1＞
　プロセッサ1が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_ALL_PRC2＞
　プロセッサ2が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_ALL_PRC3＞
　プロセッサ3が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_ALL_PRC4＞
　プロセッサ4が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_PRC1＞
　プロセッサ1が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ1のみ．

＜CLS_PRC2＞
　プロセッサ2が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ2のみ．

＜CLS_PRC3＞
　プロセッサ3が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ3のみ．

＜CLS_PRC4＞
　プロセッサ4が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ4のみ．</property>
                    <property name="active">0</property>
                    <items>
                      <item translatable="yes">CLS_ALL_PRC1</item>
                      <item translatable="yes">CLS_ALL_PRC2</item>
                      <item translatable="yes">CLS_ALL_PRC3</item>
                      <item translatable="yes">CLS_ALL_PRC4</item>
                      <item translatable="yes">CLS_PRC1</item>
                      <item translatable="yes">CLS_PRC2</item>
                      <item translatable="yes">CLS_PRC3</item>
                      <item translatable="yes">CLS_PRC4</item>
                    </items>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="spin_lock_domain">
                    <property name="name">spin_lock</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">140</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="spin_lock_acptn1">
                    <property name="name">spin_lock</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">180</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="spin_lock_acptn2">
                    <property name="name">spin_lock</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">220</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="spin_lock_acptn3">
                    <property name="name">spin_lock</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">260</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="spin_lock_acptn4">
                    <property name="name">spin_lock</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">300</property>
                  </packing>
                </child>
              </object>
              <packing>
                <property name="position">7</property>
              </packing>
            </child>
            <child type="tab">
              <object class="GtkLabel" id="label_spin_lock">
                <property name="visible">True</property>
                <property name="can_focus">False</property>
                <property name="tooltip_text" translatable="yes">スピンロックは，マルチプロセッサ対応カーネルにおいて，割込みのマスクとプロセッサ間ロックの取得により，排他制御を行うための同期・通信オブジェクトである．</property>
                <property name="label" translatable="yes">スピンロック</property>
              </object>
              <packing>
                <property name="position">7</property>
                <property name="tab_fill">False</property>
              </packing>
            </child>
            <child>
              <object class="GtkFixed">
                <property name="visible">True</property>
                <property name="can_focus">False</property>
                <child>
                  <object class="GtkButton">
                    <property name="label" translatable="yes">追加</property>
                    <property name="name">mempfix</property>
                    <property name="width_request">58</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <property name="receives_default">True</property>
                    <property name="tooltip_text" translatable="yes">固定長メモリプールを追加する</property>
                    <signal name="clicked" handler="button_add_clicked" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">10</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkButton" id="mempfix_button_update">
                    <property name="label" translatable="yes">更新</property>
                    <property name="name">mempfix</property>
                    <property name="width_request">58</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <property name="receives_default">True</property>
                    <property name="tooltip_text" translatable="yes">修正した内容で更新する
※更新せずに固定長メモリプールを変更すると変更内容が破棄される</property>
                    <signal name="clicked" handler="button_update_clicked" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">75</property>
                    <property name="y">10</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkButton">
                    <property name="label" translatable="yes">削除</property>
                    <property name="name">mempfix</property>
                    <property name="width_request">58</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <property name="receives_default">True</property>
                    <property name="tooltip_text" translatable="yes">選択中の固定長メモリプールを削除する</property>
                    <signal name="clicked" handler="button_delete_clicked" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">140</property>
                    <property name="y">10</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkComboBoxText" id="mempfix_combo_box">
                    <property name="name">mempfix</property>
                    <property name="width_request">190</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">編集する固定長メモリプールを選択する</property>
                    <signal name="changed" handler="combo_changed" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">50</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">生成する固定長メモリプールのID番号</property>
                    <property name="label" translatable="yes">固定長メモリプールID</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">固定長メモリプール属性</property>
                    <property name="label" translatable="yes">属性</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">140</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">獲得できる固定長メモリブロックの数</property>
                    <property name="label" translatable="yes">メモリブロック数</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">180</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">固定長メモリブロックのサイズ（バイト数）</property>
                    <property name="label" translatable="yes">メモリブロックサイズ</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">220</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">固定長メモリプール領域の先頭番地</property>
                    <property name="label" translatable="yes">メモリプール領域の
先頭番地</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">260</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">固定長メモリプール管理領域の先頭番地</property>
                    <property name="label" translatable="yes">管理領域の
先頭番地</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">300</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="mempfix_id">
                    <property name="name">mempfix</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkCheckButton" id="mempfix_att_tpri">
                    <property name="label" translatable="yes">TA_TPRI</property>
                    <property name="name">mempfix</property>
                    <property name="width_request">77</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <property name="receives_default">False</property>
                    <property name="tooltip_text" translatable="yes">待ち行列をタスクの優先度順にする</property>
                    <property name="halign">start</property>
                    <property name="draw_indicator">True</property>
                    <signal name="toggled" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">140</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="mempfix_blkcnt">
                    <property name="name">mempfix</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">180</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="mempfix_blksz">
                    <property name="name">mempfix</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">220</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="mempfix_mpf">
                    <property name="name">mempfix</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">260</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="mempfix_mpfmb">
                    <property name="name">mempfix</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">300</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">固定長メモリプールが所属するクラス
（クラス：マルチプロセッサに対応するために用いるカーネルオブジェクトの集合）</property>
                    <property name="label" translatable="yes">クラス</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">固定長メモリプールが所属する保護ドメイン
（保護ドメイン：保護機能を提供するために用いるカーネルオブジェクトの集合）</property>
                    <property name="label" translatable="yes">保護ドメイン</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">140</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">以下の操作が許可されるドメイン
・get_mpf
・pget_mpf
・tget_mpf</property>
                    <property name="label" translatable="yes">アクセス許可パターン
通常操作1</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">180</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">以下の操作が許可されるドメイン
・rel_mpf</property>
                    <property name="label" translatable="yes">アクセス許可パターン
通常操作2</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">220</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">以下の操作が許可されるドメイン
・del_mpf
・ini_mpf
・sac_mpf</property>
                    <property name="label" translatable="yes">アクセス許可パターン
管理操作</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">260</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">以下の操作が許可されるドメイン
・ref_mpf</property>
                    <property name="label" translatable="yes">アクセス許可パターン
参照操作</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">300</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkComboBoxText" id="mempfix_class">
                    <property name="name">mempfix</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">＜CLS_ALL_PRC1＞
　プロセッサ1が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_ALL_PRC2＞
　プロセッサ2が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_ALL_PRC3＞
　プロセッサ3が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_ALL_PRC4＞
　プロセッサ4が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_PRC1＞
　プロセッサ1が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ1のみ．

＜CLS_PRC2＞
　プロセッサ2が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ2のみ．

＜CLS_PRC3＞
　プロセッサ3が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ3のみ．

＜CLS_PRC4＞
　プロセッサ4が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ4のみ．</property>
                    <property name="active">0</property>
                    <items>
                      <item translatable="yes">CLS_ALL_PRC1</item>
                      <item translatable="yes">CLS_ALL_PRC2</item>
                      <item translatable="yes">CLS_ALL_PRC3</item>
                      <item translatable="yes">CLS_ALL_PRC4</item>
                      <item translatable="yes">CLS_PRC1</item>
                      <item translatable="yes">CLS_PRC2</item>
                      <item translatable="yes">CLS_PRC3</item>
                      <item translatable="yes">CLS_PRC4</item>
                    </items>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="mempfix_domain">
                    <property name="name">mempfix</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">140</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="mempfix_acptn1">
                    <property name="name">mempfix</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">180</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="mempfix_acptn2">
                    <property name="name">mempfix</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">220</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="mempfix_acptn3">
                    <property name="name">mempfix</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">260</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="mempfix_acptn4">
                    <property name="name">mempfix</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">300</property>
                  </packing>
                </child>
              </object>
              <packing>
                <property name="position">8</property>
              </packing>
            </child>
            <child type="tab">
              <object class="GtkLabel">
                <property name="visible">True</property>
                <property name="can_focus">False</property>
                <property name="tooltip_text" translatable="yes">固定長メモリプールは，生成時に決めたサイズのメモリブロック（固定長メモリブロック）を動的に獲得・返却するための同期・通信オブジェクトである．</property>
                <property name="label" translatable="yes">固定長メモリプール</property>
                <property name="justify">center</property>
              </object>
              <packing>
                <property name="position">8</property>
                <property name="tab_fill">False</property>
              </packing>
            </child>
            <child>
              <object class="GtkFixed">
                <property name="visible">True</property>
                <property name="can_focus">False</property>
                <child>
                  <object class="GtkButton">
                    <property name="label" translatable="yes">追加</property>
                    <property name="name">cyclic</property>
                    <property name="width_request">58</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <property name="receives_default">True</property>
                    <property name="tooltip_text" translatable="yes">周期通知を追加する</property>
                    <signal name="clicked" handler="button_add_clicked" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">10</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkButton" id="cyclic_button_update">
                    <property name="label" translatable="yes">更新</property>
                    <property name="name">cyclic</property>
                    <property name="width_request">58</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <property name="receives_default">True</property>
                    <property name="tooltip_text" translatable="yes">修正した内容で更新する
※更新せずに周期通知を変更すると変更内容が破棄される</property>
                    <signal name="clicked" handler="button_update_clicked" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">75</property>
                    <property name="y">10</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkButton">
                    <property name="label" translatable="yes">削除</property>
                    <property name="name">cyclic</property>
                    <property name="width_request">58</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <property name="receives_default">True</property>
                    <property name="tooltip_text" translatable="yes">選択中の周期通知を削除する</property>
                    <signal name="clicked" handler="button_delete_clicked" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">140</property>
                    <property name="y">10</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkComboBoxText" id="cyclic_combo_box">
                    <property name="name">cyclic</property>
                    <property name="width_request">190</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">編集する周期通知を選択する</property>
                    <signal name="changed" handler="combo_changed" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">50</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">生成する周期通知のID番号</property>
                    <property name="label" translatable="yes">周期通知ID</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">周期通知属性</property>
                    <property name="label" translatable="yes">属性</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">140</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">周期通知の通知周期</property>
                    <property name="label" translatable="yes">通知周期</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">180</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">周期通知の通知位相</property>
                    <property name="label" translatable="yes">通知位相</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">220</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="cyclic_id">
                    <property name="name">cyclic</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkCheckButton" id="cyclic_att_sta">
                    <property name="label" translatable="yes">TA_STA</property>
                    <property name="name">cyclic</property>
                    <property name="width_request">77</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <property name="receives_default">False</property>
                    <property name="tooltip_text" translatable="yes">周期通知の生成時に周期通知を動作開始する</property>
                    <property name="halign">start</property>
                    <property name="draw_indicator">True</property>
                    <signal name="toggled" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">140</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="cyclic_cyctim">
                    <property name="name">cyclic</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">180</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="cyclic_cycphs">
                    <property name="name">cyclic</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">220</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">周期通知が所属するクラス
（クラス：マルチプロセッサに対応するために用いるカーネルオブジェクトの集合）</property>
                    <property name="label" translatable="yes">クラス</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">周期通知が所属する保護ドメイン
（保護ドメイン：保護機能を提供するために用いるカーネルオブジェクトの集合）</property>
                    <property name="label" translatable="yes">保護ドメイン</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">140</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">以下の操作が許可されるドメイン
・sta_cyc
・msta_cyc</property>
                    <property name="label" translatable="yes">アクセス許可パターン
通常操作1</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">180</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">以下の操作が許可されるドメイン
・stp_cyc</property>
                    <property name="label" translatable="yes">アクセス許可パターン
通常操作2</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">220</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">以下の操作が許可されるドメイン
・del_cyc
・sac_cyc</property>
                    <property name="label" translatable="yes">アクセス許可パターン
管理操作</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">260</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">以下の操作が許可されるドメイン
・ref_cyc</property>
                    <property name="label" translatable="yes">アクセス許可パターン
参照操作</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">300</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkComboBoxText" id="cyclic_class">
                    <property name="name">cyclic</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">＜CLS_ALL_PRC1＞
　プロセッサ1が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_ALL_PRC2＞
　プロセッサ2が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_ALL_PRC3＞
　プロセッサ3が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_ALL_PRC4＞
　プロセッサ4が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_PRC1＞
　プロセッサ1が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ1のみ．

＜CLS_PRC2＞
　プロセッサ2が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ2のみ．

＜CLS_PRC3＞
　プロセッサ3が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ3のみ．

＜CLS_PRC4＞
　プロセッサ4が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ4のみ．</property>
                    <property name="active">0</property>
                    <items>
                      <item translatable="yes">CLS_ALL_PRC1</item>
                      <item translatable="yes">CLS_ALL_PRC2</item>
                      <item translatable="yes">CLS_ALL_PRC3</item>
                      <item translatable="yes">CLS_ALL_PRC4</item>
                      <item translatable="yes">CLS_PRC1</item>
                      <item translatable="yes">CLS_PRC2</item>
                      <item translatable="yes">CLS_PRC3</item>
                      <item translatable="yes">CLS_PRC4</item>
                    </items>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="cyclic_domain">
                    <property name="name">cyclic</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">140</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="cyclic_acptn1">
                    <property name="name">cyclic</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">180</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="cyclic_acptn2">
                    <property name="name">cyclic</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">220</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="cyclic_acptn3">
                    <property name="name">cyclic</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">260</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="cyclic_acptn4">
                    <property name="name">cyclic</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">300</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">36</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">タイムイベントの通知の種類を表す定数</property>
                    <property name="label" translatable="yes">タイムイベントの
通知の種類</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">360</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel" id="cyclic_nfyinfo1_label">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">タイムイベント通知の付随情報1</property>
                    <property name="label" translatable="yes">付随情報1</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">360</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel" id="cyclic_nfyinfo2_label">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">タイムイベント通知の付随情報2</property>
                    <property name="label" translatable="yes">付随情報2</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">400</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel" id="cyclic_enfytype_label">
                    <property name="width_request">110</property>
                    <property name="height_request">36</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">エラーの通知の種類を表す定数</property>
                    <property name="label" translatable="yes">エラーの
通知の種類</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">440</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel" id="cyclic_enfyinfo1_label">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">エラー通知の付随情報1</property>
                    <property name="label" translatable="yes">付随情報1</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">440</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel" id="cyclic_enfyinfo2_label">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">エラー通知の付随情報2</property>
                    <property name="label" translatable="yes">付随情報2</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">480</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkComboBoxText" id="cyclic_nfytype">
                    <property name="name">cyclic</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">TNFY_HANDLER：タイムイベントハンドラの呼出しによる通知
TNFY_SETVAR：変数の設定による通知
TNFY_INCVAR：変数のインクリメントによる通知
TNFY_ACTTSK：タスクの起動による通知
TNFY_WUPTSK：タスクの起床による通知
TNFY_SIGSEM：セマフォの返却による通知
TNFY_SETFLG：イベントフラグのセットによる通知
TNFY_SNDDTQ：データキューへの送信による通知</property>
                    <property name="active">0</property>
                    <items>
                      <item translatable="yes">TNFY_HANDLER</item>
                      <item translatable="yes">TNFY_SETVAR</item>
                      <item translatable="yes">TNFY_INCVAR</item>
                      <item translatable="yes">TNFY_ACTTSK</item>
                      <item translatable="yes">TNFY_WUPTSK</item>
                      <item translatable="yes">TNFY_SIGSEM</item>
                      <item translatable="yes">TNFY_SETFLG</item>
                      <item translatable="yes">TNFY_SNDDTQ</item>
                    </items>
                    <signal name="changed" handler="nfytype_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">360</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkComboBoxText" id="cyclic_nfyinfo1_combo">
                    <property name="name">cyclic</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">360</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="cyclic_nfyinfo1_entry">
                    <property name="name">cyclic</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">360</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="cyclic_nfyinfo2_entry">
                    <property name="name">cyclic</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">400</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkComboBoxText" id="cyclic_enfytype">
                    <property name="name">cyclic</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">TENFY_SETVAR：変数の設定による通知
TENFY_INCVAR：変数のインクリメントによる通知
TENFY_ACTTSK：タスクの起動による通知
TENFY_WUPTSK：タスクの起床による通知
TENFY_SIGSEM：セマフォの返却による通知
TENFY_SETFLG：イベントフラグのセットによる通知
TENFY_SNDDTQ：データキューへの送信による通知</property>
                    <property name="active">0</property>
                    <items>
                      <item translatable="yes">エラー通知なし</item>
                      <item translatable="yes">TENFY_SETVAR</item>
                      <item translatable="yes">TENFY_INCVAR</item>
                      <item translatable="yes">TENFY_ACTTSK</item>
                      <item translatable="yes">TENFY_WUPTSK</item>
                      <item translatable="yes">TENFY_SIGSEM</item>
                      <item translatable="yes">TENFY_SETFLG</item>
                      <item translatable="yes">TENFY_SNDDTQ</item>
                    </items>
                    <signal name="changed" handler="enfytype_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">440</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkComboBoxText" id="cyclic_enfyinfo1_combo">
                    <property name="name">cyclic</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">440</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="cyclic_enfyinfo1_entry">
                    <property name="name">cyclic</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">440</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="cyclic_enfyinfo2_entry">
                    <property name="name">cyclic</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">480</property>
                  </packing>
                </child>
              </object>
              <packing>
                <property name="position">9</property>
              </packing>
            </child>
            <child type="tab">
              <object class="GtkLabel">
                <property name="visible">True</property>
                <property name="can_focus">False</property>
                <property name="tooltip_text" translatable="yes">周期通知は，指定した周期で通知処理を行うタイムイベント通知である．</property>
                <property name="label" translatable="yes">周期通知</property>
              </object>
              <packing>
                <property name="position">9</property>
                <property name="tab_fill">False</property>
              </packing>
            </child>
            <child>
              <object class="GtkFixed">
                <property name="visible">True</property>
                <property name="can_focus">False</property>
                <child>
                  <object class="GtkButton">
                    <property name="label" translatable="yes">追加</property>
                    <property name="name">alarm</property>
                    <property name="width_request">58</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <property name="receives_default">True</property>
                    <property name="tooltip_text" translatable="yes">アラーム通知を追加する</property>
                    <signal name="clicked" handler="button_add_clicked" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">10</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkButton" id="alarm_button_update">
                    <property name="label" translatable="yes">更新</property>
                    <property name="name">alarm</property>
                    <property name="width_request">58</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <property name="receives_default">True</property>
                    <property name="tooltip_text" translatable="yes">修正した内容で更新する
※更新せずにアラーム通知を変更すると変更内容が破棄される</property>
                    <signal name="clicked" handler="button_update_clicked" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">75</property>
                    <property name="y">10</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkButton">
                    <property name="label" translatable="yes">削除</property>
                    <property name="name">alarm</property>
                    <property name="width_request">58</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <property name="receives_default">True</property>
                    <property name="tooltip_text" translatable="yes">選択中のアラーム通知を削除する</property>
                    <signal name="clicked" handler="button_delete_clicked" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">140</property>
                    <property name="y">10</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkComboBoxText" id="alarm_combo_box">
                    <property name="name">alarm</property>
                    <property name="width_request">190</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">編集するアラーム通知を選択する</property>
                    <signal name="changed" handler="combo_changed" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">50</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">生成するアラーム通知のID番号</property>
                    <property name="label" translatable="yes">アラーム通知ID</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="alarm_id">
                    <property name="name">alarm</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">アラーム通知が所属するクラス
（クラス：マルチプロセッサに対応するために用いるカーネルオブジェクトの集合）</property>
                    <property name="label" translatable="yes">クラス</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">アラーム通知が所属する保護ドメイン
（保護ドメイン：保護機能を提供するために用いるカーネルオブジェクトの集合）</property>
                    <property name="label" translatable="yes">保護ドメイン</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">140</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">以下の操作が許可されるドメイン
・sta_alm
・msta_alm</property>
                    <property name="label" translatable="yes">アクセス許可パターン
通常操作1</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">180</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">以下の操作が許可されるドメイン
・stp_alm</property>
                    <property name="label" translatable="yes">アクセス許可パターン
通常操作2</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">220</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">以下の操作が許可されるドメイン
・del_alm
・sac_alm</property>
                    <property name="label" translatable="yes">アクセス許可パターン
管理操作</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">260</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">以下の操作が許可されるドメイン
・ref_alm</property>
                    <property name="label" translatable="yes">アクセス許可パターン
参照操作</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 8"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">300</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkComboBoxText" id="alarm_class">
                    <property name="name">alarm</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">＜CLS_ALL_PRC1＞
　プロセッサ1が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_ALL_PRC2＞
　プロセッサ2が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_ALL_PRC3＞
　プロセッサ3が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_ALL_PRC4＞
　プロセッサ4が初期割付けプロセッサのクラス．
　割付け可能プロセッサはシステム上の全てのプロセッサ．

＜CLS_PRC1＞
　プロセッサ1が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ1のみ．

＜CLS_PRC2＞
　プロセッサ2が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ2のみ．

＜CLS_PRC3＞
　プロセッサ3が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ3のみ．

＜CLS_PRC4＞
　プロセッサ4が初期割付けプロセッサのクラス．
　割付け可能プロセッサはプロセッサ4のみ．</property>
                    <property name="active">0</property>
                    <items>
                      <item translatable="yes">CLS_ALL_PRC1</item>
                      <item translatable="yes">CLS_ALL_PRC2</item>
                      <item translatable="yes">CLS_ALL_PRC3</item>
                      <item translatable="yes">CLS_ALL_PRC4</item>
                      <item translatable="yes">CLS_PRC1</item>
                      <item translatable="yes">CLS_PRC2</item>
                      <item translatable="yes">CLS_PRC3</item>
                      <item translatable="yes">CLS_PRC4</item>
                    </items>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">100</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="alarm_domain">
                    <property name="name">alarm</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">140</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="alarm_acptn1">
                    <property name="name">alarm</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">180</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="alarm_acptn2">
                    <property name="name">alarm</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">220</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="alarm_acptn3">
                    <property name="name">alarm</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">260</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="alarm_acptn4">
                    <property name="name">alarm</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">300</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel">
                    <property name="width_request">110</property>
                    <property name="height_request">36</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">タイムイベントの通知の種類を表す定数</property>
                    <property name="label" translatable="yes">タイムイベントの
通知の種類</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">360</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel" id="alarm_nfyinfo1_label">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">タイムイベント通知の付随情報1</property>
                    <property name="label" translatable="yes">付随情報1</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">360</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel" id="alarm_nfyinfo2_label">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">タイムイベント通知の付随情報2</property>
                    <property name="label" translatable="yes">付随情報2</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">400</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel" id="alarm_enfytype_label">
                    <property name="width_request">110</property>
                    <property name="height_request">36</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">エラーの通知の種類を表す定数</property>
                    <property name="label" translatable="yes">エラーの
通知の種類</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">10</property>
                    <property name="y">440</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel" id="alarm_enfyinfo1_label">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">エラー通知の付随情報1</property>
                    <property name="label" translatable="yes">付随情報1</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">440</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkLabel" id="alarm_enfyinfo2_label">
                    <property name="width_request">110</property>
                    <property name="height_request">35</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">エラー通知の付随情報2</property>
                    <property name="label" translatable="yes">付随情報2</property>
                    <property name="justify">center</property>
                    <attributes>
                      <attribute name="font-desc" value="Sans 10"/>
                    </attributes>
                  </object>
                  <packing>
                    <property name="x">320</property>
                    <property name="y">480</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkComboBoxText" id="alarm_nfytype">
                    <property name="name">alarm</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">TNFY_HANDLER：タイムイベントハンドラの呼出しによる通知
TNFY_SETVAR：変数の設定による通知
TNFY_INCVAR：変数のインクリメントによる通知
TNFY_ACTTSK：タスクの起動による通知
TNFY_WUPTSK：タスクの起床による通知
TNFY_SIGSEM：セマフォの返却による通知
TNFY_SETFLG：イベントフラグのセットによる通知
TNFY_SNDDTQ：データキューへの送信による通知</property>
                    <property name="active">0</property>
                    <items>
                      <item translatable="yes">TNFY_HANDLER</item>
                      <item translatable="yes">TNFY_SETVAR</item>
                      <item translatable="yes">TNFY_INCVAR</item>
                      <item translatable="yes">TNFY_ACTTSK</item>
                      <item translatable="yes">TNFY_WUPTSK</item>
                      <item translatable="yes">TNFY_SIGSEM</item>
                      <item translatable="yes">TNFY_SETFLG</item>
                      <item translatable="yes">TNFY_SNDDTQ</item>
                    </items>
                    <signal name="changed" handler="nfytype_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">360</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkComboBoxText" id="alarm_nfyinfo1_combo">
                    <property name="name">alarm</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">360</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="alarm_nfyinfo1_entry">
                    <property name="name">alarm</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">360</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="alarm_nfyinfo2_entry">
                    <property name="name">alarm</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">400</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkComboBoxText" id="alarm_enfytype">
                    <property name="name">alarm</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <property name="tooltip_text" translatable="yes">TENFY_SETVAR：変数の設定による通知
TENFY_INCVAR：変数のインクリメントによる通知
TENFY_ACTTSK：タスクの起動による通知
TENFY_WUPTSK：タスクの起床による通知
TENFY_SIGSEM：セマフォの返却による通知
TENFY_SETFLG：イベントフラグのセットによる通知
TENFY_SNDDTQ：データキューへの送信による通知</property>
                    <property name="active">0</property>
                    <items>
                      <item translatable="yes">エラー通知なし</item>
                      <item translatable="yes">TENFY_SETVAR</item>
                      <item translatable="yes">TENFY_INCVAR</item>
                      <item translatable="yes">TENFY_ACTTSK</item>
                      <item translatable="yes">TENFY_WUPTSK</item>
                      <item translatable="yes">TENFY_SIGSEM</item>
                      <item translatable="yes">TENFY_SETFLG</item>
                      <item translatable="yes">TENFY_SNDDTQ</item>
                    </items>
                    <signal name="changed" handler="enfytype_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">130</property>
                    <property name="y">440</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkComboBoxText" id="alarm_enfyinfo1_combo">
                    <property name="name">alarm</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">False</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">440</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="alarm_enfyinfo1_entry">
                    <property name="name">alarm</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">440</property>
                  </packing>
                </child>
                <child>
                  <object class="GtkEntry" id="alarm_enfyinfo2_entry">
                    <property name="name">alarm</property>
                    <property name="width_request">168</property>
                    <property name="height_request">34</property>
                    <property name="visible">True</property>
                    <property name="can_focus">True</property>
                    <signal name="changed" handler="param_edited" swapped="no"/>
                  </object>
                  <packing>
                    <property name="x">440</property>
                    <property name="y">480</property>
                  </packing>
                </child>
              </object>
              <packing>
                <property name="position">10</property>
              </packing>
            </child>
            <child type="tab">
              <object class="GtkLabel">
                <property name="visible">True</property>
                <property name="can_focus">False</property>
                <property name="tooltip_text" translatable="yes">アラーム通知は，指定した相対時間後に通知処理を行うタイムイベント通知である．</property>
                <property name="label" translatable="yes">アラーム通知</property>
                <property name="justify">center</property>
              </object>
              <packing>
                <property name="position">10</property>
                <property name="tab_fill">False</property>
              </packing>
            </child>
          </object>
          <packing>
            <property name="x">10</property>
            <property name="y">55</property>
          </packing>
        </child>
      </object>
    </child>
  </object>
</interface>

EOS

cGladeData = REXML::Document.new(sGladeData)
cBuilder = Gtk::Builder.new(string: sGladeData)



######################################################################
# Data definition
######################################################################

$hAllCtrl = {}
$hObjCtrlId = {}
$hAllConfigData = {}
$hComboData = {}
$hAttData = {}
ALL_OBJ_LABEL.each{|lObjType|
  $hObjCtrlId[lObjType] = []
  $hComboData["#{lObjType.to_s()}_class".to_sym()] = []
  $hComboData["#{lObjType.to_s()}_nfytype".to_sym()] = []
  $hComboData["#{lObjType.to_s()}_enfytype".to_sym()] = []
  $hAttData[lObjType] = {}
  $hAllConfigData[lObjType] = {}
}

XPath.each(cGladeData, "//object"){|cElement|
  if (cElement.attributes.has_key?("id"))
    sCtrlId = cElement.attributes["id"]
    $hAllCtrl[sCtrlId.to_sym()] = cBuilder.get_object(sCtrlId)
    $hAllCtrl[sCtrlId.to_sym()].override_font(PANGO_FONT)

    if (sCtrlId =~ /^\w+_button_update$/)
      next
    end

    ALL_OBJ_LABEL.each{|lObjType|
      if (sCtrlId =~ /^#{lObjType.to_s()}_/)
        $hObjCtrlId[lObjType].push(sCtrlId.to_sym())
      end
      if (sCtrlId =~ /^#{lObjType.to_s()}_att_/)
        cElement.elements.each("property"){|cProperty|
          if (cProperty.attributes["name"] == "label")
            $hAttData[lObjType][sCtrlId.to_sym()] = cProperty.text()
          end
        }
      end
      if (sCtrlId == "#{lObjType.to_s()}_class")
        cElement.elements.each("items/item"){|cItem|
          $hComboData["#{lObjType.to_s()}_class".to_sym()].push(cItem.text())
        }
      elsif (sCtrlId == "#{lObjType.to_s()}_nfytype")
        cElement.elements.each("items/item"){|cItem|
          $hComboData["#{lObjType.to_s()}_nfytype".to_sym()].push(cItem.text())
        }
      elsif (sCtrlId == "#{lObjType.to_s()}_enfytype")
        cElement.elements.each("items/item"){|cItem|
          $hComboData["#{lObjType.to_s()}_enfytype".to_sym()].push(cItem.text())
        }
      end
    }
  end
}

$hAllCtrl[:window_main].set_title(MAIN_TITLE)



######################################################################
# Common methods
######################################################################

def message_dialog(lType, sMessage)
  cDialog = Gtk::MessageDialog.new({:parent => $hAllCtrl[:window_main], :flags => 0, :type => lType, :buttons => :ok, :message => sMessage})
  cDialog.override_font(PANGO_FONT)
  cDialog.run()
  cDialog.destroy()
end

def gen_new_id(sObjName, hExist)
  nIdx = 1
  sNewId = "#{sObjName}#{nIdx}"
  while (hExist.has_key?(sNewId))
    nIdx += 1
    sNewId = "#{sObjName}#{nIdx}"
  end
  return sNewId
end

$lCurrentProfile = nil
$hSensitiveProfileList = {[:asp3, :fmp3] => [:fixed_messagebuf, :label_messagebuf],
                          [:asp3, :hrp3] => [:fixed_spin_lock, :label_spin_lock]}
def profile_changed()
  PROFILES.each{|lProfile|
    if (($hAllCtrl[lProfile].active?) && ($lCurrentProfile != lProfile))
      $lCurrentProfile = lProfile
      $hAllConfigData[:profile] = $lCurrentProfile
      $hAllConfigData.each{|lObjType, hObjData|
        if ((lObjType != :profile) && !hObjData.empty?())
          switch_sensitive_all_obj(lObjType, true)
        end
      }
      break
    end
  }

  $hSensitiveProfileList.each{|aProfile, aList|
    bSensitive = true
    if (aProfile.include?($lCurrentProfile))
      bSensitive = false
    end
    aList.each{|lCtrlId|
      $hAllCtrl[lCtrlId].set_sensitive(bSensitive)
    }
  }

  $cTextView.buffer.set_text(generate_cfg_data())
end

$hSensitiveParamList = {}
ALL_OBJ_LABEL.each{|lObjType|
  $hSensitiveParamList[lObjType] = {}
  sObjType = lObjType.to_s()
  $hSensitiveParamList[lObjType][:hrmp3] = []
  $hSensitiveParamList[lObjType][:hrp3] = ["#{sObjType}_class".to_sym()]
  $hSensitiveParamList[lObjType][:fmp3] = ["#{sObjType}_domain".to_sym(), "#{sObjType}_acptn1".to_sym(), "#{sObjType}_acptn2".to_sym(), "#{sObjType}_acptn3".to_sym(), "#{sObjType}_acptn4".to_sym()]
  $hSensitiveParamList[lObjType][:asp3] = $hSensitiveParamList[lObjType][:fmp3] + $hSensitiveParamList[lObjType][:hrp3]
  if (lObjType == :task)
    $hSensitiveParamList[lObjType][:asp3].concat([:task_sstksz, :task_sstk])
    $hSensitiveParamList[lObjType][:fmp3].concat([:task_sstksz, :task_sstk])
  end
}

def switch_sensitive_all_obj(lObjType, bSwitch)
  if (bSwitch == false)
    $hObjCtrlId[lObjType].each{|lCtrlId|
      $hAllCtrl[lCtrlId].set_sensitive(false)
    }
  else
    aTargetList = $hSensitiveParamList[lObjType][$lCurrentProfile]
    $hObjCtrlId[lObjType].each{|lCtrlId|
      if (aTargetList.include?(lCtrlId))
        $hAllCtrl[lCtrlId].set_sensitive(false)
      else
        $hAllCtrl[lCtrlId].set_sensitive(true)
      end
    }
  end
end

$hParamTypeList = {}
ALL_OBJ_LABEL.each{|lObjType|
  $hParamTypeList[lObjType] = {}
  sObjType = lObjType.to_s()
  $hParamTypeList[lObjType][:id] = "#{sObjType}_id".to_sym()
  $hParamTypeList[lObjType][:text] = ["#{sObjType}_domain".to_sym(), "#{sObjType}_acptn1".to_sym(), "#{sObjType}_acptn2".to_sym(), "#{sObjType}_acptn3".to_sym(), "#{sObjType}_acptn4".to_sym()]
  $hParamTypeList[lObjType][:combo] = ["#{sObjType}_class".to_sym()]
  case lObjType
  when :task
    $hParamTypeList[lObjType][:jpn] = "タスク"
    $hParamTypeList[lObjType][:check] = [:task_att_act, :task_att_noactque, :task_att_rstr]
    $hParamTypeList[lObjType][:text].concat([:task_exinf, :task_task, :task_itskpri, :task_stksz, :task_stk, :task_sstksz, :task_sstk])
  when :semaphore
    $hParamTypeList[lObjType][:jpn] = "セマフォ"
    $hParamTypeList[lObjType][:check] = [:semaphore_att_tpri]
    $hParamTypeList[lObjType][:text].concat([:semaphore_isemcnt, :semaphore_maxsem])
  when :eventflag
    $hParamTypeList[lObjType][:jpn] = "イベントフラグ"
    $hParamTypeList[lObjType][:check] = [:eventflag_att_tpri, :eventflag_att_wmul, :eventflag_att_clr]
    $hParamTypeList[lObjType][:text].concat([:eventflag_iflgptn])
  when :dataqueue
    $hParamTypeList[lObjType][:jpn] = "データキュー"
    $hParamTypeList[lObjType][:check] = [:dataqueue_att_tpri]
    $hParamTypeList[lObjType][:text].concat([:dataqueue_dtqcnt, :dataqueue_dtqmb])
  when :pridataq
    $hParamTypeList[lObjType][:jpn] = "優先度データキュー"
    $hParamTypeList[lObjType][:check] = [:pridataq_att_tpri]
    $hParamTypeList[lObjType][:text].concat([:pridataq_dtqcnt, :pridataq_maxdpri, :pridataq_dtqmb])
  when :mutex
    $hParamTypeList[lObjType][:jpn] = "ミューテックス"
    $hParamTypeList[lObjType][:check] = [:mutex_att_tpri, :mutex_att_ceiling]
    $hParamTypeList[lObjType][:text].concat([:mutex_ceilpri])
  when :messagebuf
    $hParamTypeList[lObjType][:jpn] = "メッセージバッファ"
    $hParamTypeList[lObjType][:check] = []
    $hParamTypeList[lObjType][:text].concat([:messagebuf_maxmsz, :messagebuf_mbfsz, :messagebuf_mbfmb])
  when :spin_lock
    $hParamTypeList[lObjType][:jpn] = "スピンロック"
    $hParamTypeList[lObjType][:check] = [:spin_lock_att_native]
  when :mempfix
    $hParamTypeList[lObjType][:jpn] = "固定長メモリプール"
    $hParamTypeList[lObjType][:check] = [:mempfix_att_tpri]
    $hParamTypeList[lObjType][:text].concat([:mempfix_blkcnt, :mempfix_blksz, :mempfix_mpf, :mempfix_mpfmb])
  when :cyclic
    $hParamTypeList[lObjType][:jpn] = "周期通知"
    $hParamTypeList[lObjType][:check] = [:cyclic_att_sta]
    $hParamTypeList[lObjType][:combo].concat([:cyclic_nfytype, :cyclic_nfyinfo1_combo, :cyclic_enfytype, :cyclic_enfyinfo1_combo])
    $hParamTypeList[lObjType][:text].concat([:cyclic_cyctim, :cyclic_cycphs, :cyclic_nfyinfo1_entry, :cyclic_nfyinfo2_entry, :cyclic_enfyinfo1_entry, :cyclic_enfyinfo2_entry])
  when :alarm
    $hParamTypeList[lObjType][:jpn] = "アラーム通知"
    $hParamTypeList[lObjType][:check] = []
    $hParamTypeList[lObjType][:combo].concat([:alarm_nfytype, :alarm_nfyinfo1_combo, :alarm_enfytype, :alarm_enfyinfo1_combo])
    $hParamTypeList[lObjType][:text].concat([:alarm_nfyinfo1_entry, :alarm_nfyinfo2_entry, :alarm_enfyinfo1_entry, :alarm_enfyinfo2_entry])
  end
}

def set_all_obj(lObjType, sObjId)
  hTargetList = $hParamTypeList[lObjType]
  hTargetData = $hAllConfigData[lObjType][sObjId]
  lTypeCtrlId = "#{lObjType.to_s()}_nfytype".to_sym()
  lErrTypeCtrlId = "#{lObjType.to_s()}_enfytype".to_sym()
  lInfo1ComboCtrlId = "#{lObjType.to_s()}_nfyinfo1_combo".to_sym()
  lErrInfo1ComboCtrlId = "#{lObjType.to_s()}_enfyinfo1_combo".to_sym()

  $hAllCtrl[hTargetList[:id]].text = sObjId

  if ([:cyclic, :alarm].include?(lObjType))
    $hAllCtrl[lTypeCtrlId].set_active($hComboData[lTypeCtrlId].index(hTargetData[lTypeCtrlId]))
    nfytype_edited($hAllCtrl[lTypeCtrlId])
    $hAllCtrl[lErrTypeCtrlId].set_active($hComboData[lErrTypeCtrlId].index(hTargetData[lErrTypeCtrlId]))
    enfytype_edited($hAllCtrl[lErrTypeCtrlId])
  end

  $hObjCtrlId[lObjType].each{|lCtrlId|
    if (hTargetList[:text].include?(lCtrlId))
      $hAllCtrl[lCtrlId].text = hTargetData[lCtrlId]
    elsif (hTargetList[:check].include?(lCtrlId))
      $hAllCtrl[lCtrlId].set_active(hTargetData[lCtrlId])
    elsif (hTargetList[:combo].include?(lCtrlId))
      if (hTargetData[lCtrlId] != "")
        if ((lCtrlId == lInfo1ComboCtrlId) || (lCtrlId == lErrInfo1ComboCtrlId))
          lTargetCtrlId = lTypeCtrlId
          if (lCtrlId == lErrInfo1ComboCtrlId)
            lTargetCtrlId = lErrTypeCtrlId
          end

          case hTargetData[lTargetCtrlId].split("_")[-1]
          when "ACTTSK", "WUPTSK"
            $hAllCtrl[lCtrlId].set_active($hAllConfigData[:task].keys().index(hTargetData[lCtrlId]))
          when "SIGSEM"
            $hAllCtrl[lCtrlId].set_active($hAllConfigData[:semaphore].keys().index(hTargetData[lCtrlId]))
          when "SETFLG"
            $hAllCtrl[lCtrlId].set_active($hAllConfigData[:eventflag].keys().index(hTargetData[lCtrlId]))
          when "SNDDTQ"
            $hAllCtrl[lCtrlId].set_active($hAllConfigData[:dataqueue].keys().index(hTargetData[lCtrlId]))
          end
        else
          $hAllCtrl[lCtrlId].set_active($hComboData[lCtrlId].index(hTargetData[lCtrlId]))
        end
      end
    end
  }
end

$hInitialValueList = {}
ALL_OBJ_LABEL.each{|lObjType|
  $hInitialValueList[lObjType] = {}
  sObjType = lObjType.to_s()
  $hInitialValueList[lObjType] = {"#{sObjType}_class".to_sym() => "CLS_ALL_PRC1",
                                  "#{sObjType}_domain".to_sym() => "KERNEL_DOMAIN",
                                  "#{sObjType}_acptn1".to_sym() => "",
                                  "#{sObjType}_acptn2".to_sym() => "",
                                  "#{sObjType}_acptn3".to_sym() => "",
                                  "#{sObjType}_acptn4".to_sym() => ""}
  case lObjType
  when :task
    $hInitialValueList[lObjType][:task_att_act] = false
    $hInitialValueList[lObjType][:task_att_noactque] = false
    $hInitialValueList[lObjType][:task_att_rstr] = false
    $hInitialValueList[lObjType][:task_exinf] = "NULL"
    $hInitialValueList[lObjType][:task_task] = nil
    $hInitialValueList[lObjType][:task_itskpri] = "15"
    $hInitialValueList[lObjType][:task_stksz] = "256"
    $hInitialValueList[lObjType][:task_stk] = ""
    $hInitialValueList[lObjType][:task_sstksz] = ""
    $hInitialValueList[lObjType][:task_sstk] = ""
  when :semaphore
    $hInitialValueList[lObjType][:semaphore_att_tpri] = false
    $hInitialValueList[lObjType][:semaphore_isemcnt] = "5"
    $hInitialValueList[lObjType][:semaphore_maxsem] = "5"
  when :eventflag
    $hInitialValueList[lObjType][:eventflag_att_tpri] = false
    $hInitialValueList[lObjType][:eventflag_att_wmul] = false
    $hInitialValueList[lObjType][:eventflag_att_clr] = false
    $hInitialValueList[lObjType][:eventflag_iflgptn] = "1"
  when :dataqueue
    $hInitialValueList[lObjType][:dataqueue_att_tpri] = false
    $hInitialValueList[lObjType][:dataqueue_dtqcnt] = "5"
    $hInitialValueList[lObjType][:dataqueue_dtqmb] = ""
  when :pridataq
    $hInitialValueList[lObjType][:pridataq_att_tpri] = false
    $hInitialValueList[lObjType][:pridataq_dtqcnt] = "5"
    $hInitialValueList[lObjType][:pridataq_maxdpri] = "5"
    $hInitialValueList[lObjType][:pridataq_dtqmb] = ""
  when :mutex
    $hInitialValueList[lObjType][:mutex_att_tpri] = false
    $hInitialValueList[lObjType][:mutex_att_ceiling] = false
    $hInitialValueList[lObjType][:mutex_ceilpri] = "10"
  when :messagebuf
    $hInitialValueList[lObjType][:messagebuf_maxmsz] = "64"
    $hInitialValueList[lObjType][:messagebuf_mbfsz] = "16"
    $hInitialValueList[lObjType][:messagebuf_mbfmb] = ""
  when :spin_lock
    $hInitialValueList[lObjType][:spin_lock_att_native] = false
  when :mempfix
    $hInitialValueList[lObjType][:mempfix_att_tpri] = false
    $hInitialValueList[lObjType][:mempfix_blkcnt] = "5"
    $hInitialValueList[lObjType][:mempfix_blksz] = "16"
    $hInitialValueList[lObjType][:mempfix_mpf] = ""
    $hInitialValueList[lObjType][:mempfix_mpfmb] = ""
  when :cyclic
    $hInitialValueList[lObjType][:cyclic_att_sta] = false
    $hInitialValueList[lObjType][:cyclic_nfytype] = "TNFY_HANDLER"
    $hInitialValueList[lObjType][:cyclic_nfyinfo1_combo] = ""
    $hInitialValueList[lObjType][:cyclic_enfytype] = "エラー通知なし"
    $hInitialValueList[lObjType][:cyclic_enfyinfo1_combo] = ""
    $hInitialValueList[lObjType][:cyclic_nfyinfo1_entry] = ""
    $hInitialValueList[lObjType][:cyclic_nfyinfo2_entry] = ""
    $hInitialValueList[lObjType][:cyclic_enfyinfo1_entry] = ""
    $hInitialValueList[lObjType][:cyclic_enfyinfo2_entry] = ""
    $hInitialValueList[lObjType][:cyclic_cyctim] = "100"
    $hInitialValueList[lObjType][:cyclic_cycphs] = "100"
  when :alarm
    $hInitialValueList[lObjType][:alarm_nfytype] = "TNFY_HANDLER"
    $hInitialValueList[lObjType][:alarm_nfyinfo1_combo] = ""
    $hInitialValueList[lObjType][:alarm_enfytype] = "エラー通知なし"
    $hInitialValueList[lObjType][:alarm_enfyinfo1_combo] = ""
    $hInitialValueList[lObjType][:alarm_nfyinfo1_entry] = ""
    $hInitialValueList[lObjType][:alarm_nfyinfo2_entry] = ""
    $hInitialValueList[lObjType][:alarm_enfyinfo1_entry] = ""
    $hInitialValueList[lObjType][:alarm_enfyinfo2_entry] = ""
  end
}

def button_add_clicked(cObject)
  lObjType = cObject.name().to_sym()
  lComboCtrlId = "#{cObject.name()}_combo_box".to_sym()
  sNewTaskId = gen_new_id(cObject.name().upcase(), $hAllConfigData[lObjType])

  hTargetInitVal = $hInitialValueList[lObjType].dup()
  if (lObjType == :task)
    hTargetInitVal[:task_task] = sNewTaskId.downcase()
  end
  $hAllConfigData[lObjType][sNewTaskId] = hTargetInitVal

  $hAllCtrl[lComboCtrlId].append_text(sNewTaskId)
  $hAllCtrl[lComboCtrlId].set_active($hAllConfigData[lObjType].keys().index(sNewTaskId))
  switch_sensitive_all_obj(lObjType, true)

  $cTextView.buffer.set_text(generate_cfg_data())
end

def button_update_clicked(cObject)
  sObjType = cObject.name()
  lObjType = sObjType.to_sym()
  lComboCtrlId = "#{cObject.name()}_combo_box".to_sym()
  lButtonCtrlId = "#{cObject.name()}_button_update".to_sym()
  lObjIdCtrlId = "#{cObject.name()}_id".to_sym()

  if ($hAllConfigData[lObjType].empty?())
    return
  end

  sNewId = $hAllCtrl[lObjIdCtrlId].text
  sCurId = $hAllCtrl[lComboCtrlId].active_text()
  if (sNewId == "")
    message_dialog(:warning, "#{$hParamTypeList[lObjType][:jpn]}IDは必須です")
    return
  elsif ((sNewId != sCurId) && $hAllConfigData[lObjType].has_key?(sNewId))
    message_dialog(:warning, "この#{$hParamTypeList[lObjType][:jpn]}IDは既に存在しています")
    return
  end

  if (sNewId != sCurId)
    nPosition = $hAllConfigData[lObjType].keys().index(sCurId)
    $hAllConfigData[lObjType].delete(sCurId)
    $hAllCtrl[lComboCtrlId].remove(nPosition)

    $hAllCtrl[lComboCtrlId].append_text(sNewId)
    $hAllConfigData[lObjType][sNewId] = {}
  end

  hTargetList = $hParamTypeList[lObjType]
  hTargetData = $hAllConfigData[lObjType][sNewId]
  $hObjCtrlId[lObjType].each{|lCtrlId|
    if (hTargetList[:text].include?(lCtrlId))
      hTargetData[lCtrlId] = $hAllCtrl[lCtrlId].text
    elsif (hTargetList[:check].include?(lCtrlId))
      hTargetData[lCtrlId] = $hAllCtrl[lCtrlId].active?
    elsif (hTargetList[:combo].include?(lCtrlId))
      hTargetData[lCtrlId] = $hAllCtrl[lCtrlId].active_text()
    end
  }

  if ([:cyclic, :alarm].include?(lObjType))
    if (["TNFY_HANDLER", "TNFY_SETVAR", "TNFY_INCVAR"].include?(hTargetData["#{sObjType}_nfytype".to_sym()]))
      hTargetData["#{sObjType}_nfyinfo1_combo".to_sym()] = ""
      hTargetData["#{sObjType}_enfytype".to_sym()] = "エラー通知なし"
    end
    if (["エラー通知なし", "TENFY_SETVAR", "TENFY_INCVAR"].include?(hTargetData["#{sObjType}_enfytype".to_sym()]))
      hTargetData["#{sObjType}_enfyinfo1_combo".to_sym()] = ""
    end
  end

  $hAllCtrl[lComboCtrlId].set_active($hAllConfigData[lObjType].keys().index(sNewId))
  $hAllCtrl[lButtonCtrlId].override_color(:normal, COLOR_DEFAULT)

  $cTextView.buffer.set_text(generate_cfg_data())
end

def button_delete_clicked(cObject)
  lObjType = cObject.name().to_sym()
  lComboCtrlId = "#{cObject.name()}_combo_box".to_sym()
  lButtonCtrlId = "#{cObject.name()}_button_update".to_sym()

  if ($hAllConfigData[lObjType].empty?())
    return
  end

  sDeleteId = $hAllCtrl[lComboCtrlId].active_text()

  [:cyclic, :alarm].each{|lTimeObjType|
    $hAllConfigData[lTimeObjType].each{|sTimeObjId, hTimeObjData|
      if ((hTimeObjData["#{lTimeObjType.to_s()}_nfyinfo1_combo".to_sym()] == sDeleteId) ||
          (hTimeObjData["#{lTimeObjType.to_s()}_enfyinfo1_combo".to_sym()] == sDeleteId))
        message_dialog(:warning, "#{sDeleteId}は，#{sTimeObjId}に使用されているため，削除できません")
        return
      end
    }
  }

  nPosition = $hAllConfigData[lObjType].keys().index(sDeleteId)
  $hAllConfigData[lObjType].delete(sDeleteId)
  $hAllCtrl[lComboCtrlId].remove(nPosition)

  if ($hAllConfigData[lObjType].empty?())
    hTargetList = $hParamTypeList[lObjType]
    $hObjCtrlId[lObjType].each{|lCtrlId|
      if ((hTargetList[:id] == lCtrlId) || hTargetList[:text].include?(lCtrlId))
        $hAllCtrl[lCtrlId].text = ""
      elsif (hTargetList[:check].include?(lCtrlId))
        $hAllCtrl[lCtrlId].set_active(false)
      elsif (hTargetList[:combo].include?(lCtrlId))
        $hAllCtrl[lCtrlId].set_active(0)
      end
    }
    switch_sensitive_all_obj(lObjType, false)
  else
    $hAllCtrl[lComboCtrlId].set_active($hAllConfigData[lObjType].size() - 1)
  end

  $hAllCtrl[lButtonCtrlId].override_color(:normal, COLOR_DEFAULT)

  $cTextView.buffer.set_text(generate_cfg_data())
end

def combo_changed(cObject)
  lObjType = cObject.name().to_sym()
  lComboCtrlId = "#{cObject.name()}_combo_box".to_sym()
  lButtonCtrlId = "#{cObject.name()}_button_update".to_sym()

  sActiveId = $hAllCtrl[lComboCtrlId].active_text()
  if ($hAllConfigData[lObjType].has_key?(sActiveId))
    set_all_obj(lObjType, sActiveId)
  end
  sActiveId = $hAllCtrl[lComboCtrlId].active_text()
  $hAllCtrl[lButtonCtrlId].override_color(:normal, COLOR_DEFAULT)
end

def param_edited(cObject)
  lButtonCtrlId = "#{cObject.name()}_button_update".to_sym()
  $hAllCtrl[lButtonCtrlId].override_color(:normal, COLOR_EDITED)
end

NFY_AREA_SETTING = {"HANDLER" => {:INFO1_TYPE => nil,
                                  :INFO1_LABEL => "拡張情報", :INFO1_TOOLTIP => "タイムイベントハンドラの拡張情報",
                                  :INFO2_LABEL => "先頭番地", :INFO2_TOOLTIP => "タイムイベントハンドラの先頭番地",
                                  :ENFY_USE => false},
                    "SETVAR" => {:INFO1_TYPE => nil,
                                 :INFO1_LABEL => "変数の番地", :INFO1_TOOLTIP => "変数の番地",
                                 :INFO2_LABEL => "設定する値", :INFO2_TOOLTIP => "設定する値",
                                 :ENFY_USE => false},
                    "INCVAR" => {:INFO1_TYPE => nil,
                                 :INFO1_LABEL => "変数の番地", :INFO1_TOOLTIP => "変数の番地",
                                 :INFO2_LABEL => nil, :INFO2_TOOLTIP => nil,
                                 :ENFY_USE => false},
                    "ACTTSK" => {:INFO1_TYPE => :task,
                                 :INFO1_LABEL => "タスクID", :INFO1_TOOLTIP => "対象タスクのタスクID",
                                 :INFO2_LABEL => nil, :INFO2_TOOLTIP => nil,
                                 :ENFY_USE => true},
                    "WUPTSK" => {:INFO1_TYPE => :task,
                                 :INFO1_LABEL => "タスクID", :INFO1_TOOLTIP => "対象タスクのタスクID",
                                 :INFO2_LABEL => nil, :INFO2_TOOLTIP => nil,
                                 :ENFY_USE => true},
                    "SIGSEM" => {:INFO1_TYPE => :semaphore,
                                 :INFO1_LABEL => "セマフォID", :INFO1_TOOLTIP => "対象セマフォのセマフォID",
                                 :INFO2_LABEL => nil, :INFO2_TOOLTIP => nil,
                                 :ENFY_USE => true},
                    "SETFLG" => {:INFO1_TYPE => :eventflag,
                                 :INFO1_LABEL => "イベントフラグID", :INFO1_TOOLTIP => "対象イベントフラグのイベントフラグID",
                                 :INFO2_LABEL => "ビットパターン", :INFO2_TOOLTIP => "セットするビットパターン",
                                 :ENFY_USE => true},
                    "SNDDTQ" => {:INFO1_TYPE => :dataqueue,
                                 :INFO1_LABEL => "データキューID", :INFO1_TOOLTIP => "対象データキューのデータキューID",
                                 :INFO2_LABEL => "送信する値", :INFO2_TOOLTIP => "送信する値",
                                 :ENFY_USE => true}}

def nfytype_edited(cObject)
  sObjType = cObject.name()
  lTypeCtrlId = "#{sObjType}_nfytype".to_sym()
  lInfo1LabelCtrlId = "#{sObjType}_nfyinfo1_label".to_sym()
  lInfo2LabelCtrlId = "#{sObjType}_nfyinfo2_label".to_sym()
  lInfo1EntryCtrlId = "#{sObjType}_nfyinfo1_entry".to_sym()
  lInfo1ComboCtrlId = "#{sObjType}_nfyinfo1_combo".to_sym()
  lInfo2EntryCtrlId = "#{sObjType}_nfyinfo2_entry".to_sym()
  lErrTypeCtrlId = "#{sObjType}_enfytype".to_sym()
  lErrTypeLabelCtrlId = "#{sObjType}_enfytype_label".to_sym()
  lErrInfo1LabelCtrlId = "#{sObjType}_enfyinfo1_label".to_sym()
  lErrInfo2LabelCtrlId = "#{sObjType}_enfyinfo2_label".to_sym()
  lErrInfo1EntryCtrlId = "#{sObjType}_enfyinfo1_entry".to_sym()
  lErrInfo1ComboCtrlId = "#{sObjType}_enfyinfo1_combo".to_sym()
  lErrInfo2EntryCtrlId = "#{sObjType}_enfyinfo2_entry".to_sym()

  hNfyAreaSetting = NFY_AREA_SETTING[$hAllCtrl[lTypeCtrlId].active_text().split("_")[1]]

  if (!hNfyAreaSetting[:INFO1_TYPE].nil?)
    if ($hAllConfigData[hNfyAreaSetting[:INFO1_TYPE]].empty?)
      message_dialog(:warning, "#{$hParamTypeList[hNfyAreaSetting[:INFO1_TYPE]][:jpn]}が1つも設定されていません")
      lComboCtrlId = "#{sObjType}_combo_box".to_sym()
      sCurObjId = $hAllCtrl[lComboCtrlId].active_text()
      $hAllCtrl[lTypeCtrlId].set_active($hComboData[lTypeCtrlId].index($hAllConfigData[sObjType.to_sym()][sCurObjId][lTypeCtrlId]))
      return
    end
    $hAllCtrl[lInfo1EntryCtrlId].hide()
    $hAllCtrl[lInfo1ComboCtrlId].show()
    $hAllCtrl[lInfo1ComboCtrlId].remove_all()
    $hAllConfigData[hNfyAreaSetting[:INFO1_TYPE]].each{|sObjId, _|
      $hAllCtrl[lInfo1ComboCtrlId].append_text(sObjId)
    }
    $hAllCtrl[lInfo1ComboCtrlId].set_active(0)
  else
    $hAllCtrl[lInfo1EntryCtrlId].show()
    $hAllCtrl[lInfo1EntryCtrlId].set_text("")
    $hAllCtrl[lInfo1ComboCtrlId].hide()
  end
  $hAllCtrl[lInfo1LabelCtrlId].set_text(hNfyAreaSetting[:INFO1_LABEL])
  $hAllCtrl[lInfo1LabelCtrlId].set_tooltip_text(hNfyAreaSetting[:INFO1_TOOLTIP])

  if (!hNfyAreaSetting[:INFO2_LABEL].nil? && !hNfyAreaSetting[:INFO2_TOOLTIP].nil?)
    $hAllCtrl[lInfo2LabelCtrlId].show()
    $hAllCtrl[lInfo2LabelCtrlId].set_text(hNfyAreaSetting[:INFO2_LABEL])
    $hAllCtrl[lInfo2LabelCtrlId].set_tooltip_text(hNfyAreaSetting[:INFO2_TOOLTIP])
    $hAllCtrl[lInfo2EntryCtrlId].show()
    $hAllCtrl[lInfo2EntryCtrlId].set_text("")
  else
    $hAllCtrl[lInfo2LabelCtrlId].hide()
    $hAllCtrl[lInfo2EntryCtrlId].hide()
  end

  if (hNfyAreaSetting[:ENFY_USE] == true)
    $hAllCtrl[lErrTypeCtrlId].show()
    $hAllCtrl[lErrTypeCtrlId].set_active(0)
    $hAllCtrl[lErrTypeLabelCtrlId].show()
  else
    $hAllCtrl[lErrTypeCtrlId].hide()
    $hAllCtrl[lErrTypeLabelCtrlId].hide()
  end
  $hAllCtrl[lErrInfo1LabelCtrlId].hide()
  $hAllCtrl[lErrInfo1EntryCtrlId].hide()
  $hAllCtrl[lErrInfo1ComboCtrlId].hide()
  $hAllCtrl[lErrInfo2LabelCtrlId].hide()
  $hAllCtrl[lErrInfo2EntryCtrlId].hide()

  param_edited(cObject)
end

def enfytype_edited(cObject)
  sObjType = cObject.name()
  lErrTypeCtrlId = "#{sObjType}_enfytype".to_sym()
  lErrInfo1LabelCtrlId = "#{sObjType}_enfyinfo1_label".to_sym()
  lErrInfo2LabelCtrlId = "#{sObjType}_enfyinfo2_label".to_sym()
  lErrInfo1EntryCtrlId = "#{sObjType}_enfyinfo1_entry".to_sym()
  lErrInfo1ComboCtrlId = "#{sObjType}_enfyinfo1_combo".to_sym()
  lErrInfo2EntryCtrlId = "#{sObjType}_enfyinfo2_entry".to_sym()

  sSelectType = $hAllCtrl[lErrTypeCtrlId].active_text()
  if (sSelectType == "エラー通知なし")
    $hAllCtrl[lErrInfo1LabelCtrlId].hide()
    $hAllCtrl[lErrInfo1EntryCtrlId].hide()
    $hAllCtrl[lErrInfo1ComboCtrlId].hide()
    $hAllCtrl[lErrInfo2LabelCtrlId].hide()
    $hAllCtrl[lErrInfo2EntryCtrlId].hide()
    param_edited(cObject)
    return
  end

  sErrType = sSelectType.split("_")[1]
  hNfyAreaSetting = NFY_AREA_SETTING[sErrType].dup()
  if ((sErrType == "SETVAR") || (sErrType == "SNDDTQ"))
    hNfyAreaSetting.delete(:INFO2_LABEL)
  end

  if (!hNfyAreaSetting[:INFO1_TYPE].nil?)
    if ($hAllConfigData[hNfyAreaSetting[:INFO1_TYPE]].empty?)
      message_dialog(:warning, "#{$hParamTypeList[hNfyAreaSetting[:INFO1_TYPE]][:jpn]}が1つも設定されていません")
      lComboCtrlId = "#{sObjType}_combo_box".to_sym()
      sCurObjId = $hAllCtrl[lComboCtrlId].active_text()
      $hAllCtrl[lErrTypeCtrlId].set_active($hComboData[lErrTypeCtrlId].index($hAllConfigData[sObjType.to_sym()][sCurObjId][lErrTypeCtrlId]))
      return
    end
    $hAllCtrl[lErrInfo1EntryCtrlId].hide()
    $hAllCtrl[lErrInfo1ComboCtrlId].show()
    $hAllCtrl[lErrInfo1ComboCtrlId].remove_all()
    $hAllConfigData[hNfyAreaSetting[:INFO1_TYPE]].each{|sObjId, _|
      $hAllCtrl[lErrInfo1ComboCtrlId].append_text(sObjId)
    }
    $hAllCtrl[lErrInfo1ComboCtrlId].set_active(0)
  else
    $hAllCtrl[lErrInfo1EntryCtrlId].show()
    $hAllCtrl[lErrInfo1EntryCtrlId].set_text("")
    $hAllCtrl[lErrInfo1ComboCtrlId].hide()
  end
  $hAllCtrl[lErrInfo1LabelCtrlId].show()
  $hAllCtrl[lErrInfo1LabelCtrlId].set_text(hNfyAreaSetting[:INFO1_LABEL])
  $hAllCtrl[lErrInfo1LabelCtrlId].set_tooltip_text(hNfyAreaSetting[:INFO1_TOOLTIP])

  if (!hNfyAreaSetting[:INFO2_LABEL].nil? && !hNfyAreaSetting[:INFO2_TOOLTIP].nil?)
    $hAllCtrl[lErrInfo2LabelCtrlId].show()
    $hAllCtrl[lErrInfo2LabelCtrlId].set_text(hNfyAreaSetting[:INFO2_LABEL])
    $hAllCtrl[lErrInfo2LabelCtrlId].set_tooltip_text(hNfyAreaSetting[:INFO2_TOOLTIP])
    $hAllCtrl[lErrInfo2EntryCtrlId].show()
    $hAllCtrl[lErrInfo2EntryCtrlId].set_text("")
  else
    $hAllCtrl[lErrInfo2LabelCtrlId].hide()
    $hAllCtrl[lErrInfo2EntryCtrlId].hide()
  end

  param_edited(cObject)
end

ALL_OBJ_LABEL.each{|lObjType|
  switch_sensitive_all_obj(lObjType, false)
}



######################################################################
# Generate Static API
######################################################################

def generate_attribute(lObjType, hObjData)
  aAtt = []
  $hAttData[lObjType].each{|lAtt, sAtt|
    if (hObjData[lAtt] == true)
      aAtt.push(sAtt)
    end
  }
  if (aAtt.empty?)
    return "TA_NULL"
  else
    return aAtt.join(" | ")
  end
end

def generate_cre_api(lObjType, sObjId)
  hObjData = $hAllConfigData[lObjType][sObjId]
  sOption = ""
  case lObjType
  when :task
    if (!hObjData[:task_stk].empty?)
      sOption += ", #{hObjData[:task_stk]}"
      if (!hObjData[:task_sstksz].empty? && [:hrp3, :hrmp3].include?($lCurrentProfile))
        sOption += ", #{hObjData[:task_sstksz]}"
        if (!hObjData[:task_sstk].empty?)
          sOption += ", #{hObjData[:task_sstk]}"
        end
      end
    end
    return "CRE_TSK(#{sObjId}, {#{generate_attribute(:task, hObjData)}, #{hObjData[:task_exinf]}, #{hObjData[:task_task]}, #{hObjData[:task_itskpri]}, #{hObjData[:task_stksz]}#{sOption}});"
  when :semaphore
    return "CRE_SEM(#{sObjId}, {#{generate_attribute(:semaphore, hObjData)}, #{hObjData[:semaphore_isemcnt]}, #{hObjData[:semaphore_maxsem]}});"
  when :eventflag
    return "CRE_FLG(#{sObjId}, {#{generate_attribute(:eventflag, hObjData)}, #{hObjData[:eventflag_iflgptn]}});"
  when :dataqueue
    if (!hObjData[:dataqueue_dtqmb].empty?)
      sOption += ", #{hObjData[:dataqueue_dtqmb]}"
    end
    return "CRE_DTQ(#{sObjId}, {#{generate_attribute(:dataqueue, hObjData)}, #{hObjData[:dataqueue_dtqcnt]}#{sOption}});"
  when :pridataq
    if (!hObjData[:pridataq_dtqmb].empty?)
      sOption += ", #{hObjData[:pridataq_dtqmb]}"
    end
    return "CRE_PDQ(#{sObjId}, {#{generate_attribute(:pridataq, hObjData)}, #{hObjData[:pridataq_dtqcnt]}, #{hObjData[:pridataq_maxdpri]}#{sOption}});"
  when :mutex
    if (!hObjData[:mutex_ceilpri].empty?)
      sOption += ", #{hObjData[:mutex_ceilpri]}"
    end
    return "CRE_MTX(#{sObjId}, {#{generate_attribute(:mutex, hObjData)}#{sOption}});"
  when :messagebuf
    if (!hObjData[:messagebuf_mbfmb].empty?)
      sOption += ", #{hObjData[:messagebuf_mbfmb]}"
    end
    return "CRE_MBF(#{sObjId}, {TA_NULL, #{hObjData[:messagebuf_maxmsz]}, #{hObjData[:messagebuf_mbfsz]}#{sOption}});"
  when :spin_lock
    return "CRE_SPN(#{sObjId}, {#{generate_attribute(:spin_lock, hObjData)}});"
  when :mempfix
    if (!hObjData[:mempfix_mpf].empty?)
      sOption += ", #{hObjData[:mempfix_mpf]}"
      if (!hObjData[:mempfix_mpfmb].empty?)
        sOption += ", #{hObjData[:mempfix_mpfmb]}"
      end
    end
    return "CRE_MPF(#{sObjId}, {#{generate_attribute(:mempfix, hObjData)}, #{hObjData[:mempfix_blkcnt]}, #{hObjData[:mempfix_blksz]}#{sOption}});"
  when :cyclic, :alarm
    sObjType = lObjType.to_sym()
    lTypeCtrlId = "#{sObjType}_nfytype".to_sym()
    lErrTypeCtrlId = "#{sObjType}_enfytype".to_sym()

    aType = [hObjData[lTypeCtrlId]]
    aInfo = [hObjData["#{sObjType}_nfyinfo1_entry".to_sym()]]
    if (!["TNFY_HANDLER", "TNFY_SETVAR", "TNFY_INCVAR"].include?(hObjData[lTypeCtrlId]))
      aInfo[0] = hObjData["#{sObjType}_nfyinfo1_combo".to_sym()]
    end
    if (["TNFY_HANDLER", "TNFY_SETVAR", "TNFY_SETFLG", "TNFY_SNDDTQ"].include?(hObjData[lTypeCtrlId]))
      aInfo.push(hObjData["#{sObjType}_nfyinfo2_entry".to_sym()])
    end

    if (hObjData[lErrTypeCtrlId] != "エラー通知なし")
      aType.push(hObjData[lErrTypeCtrlId])
      aInfo.push(hObjData["#{sObjType}_enfyinfo1_entry".to_sym()])
      if (!["TENFY_SETVAR", "TENFY_INCVAR"].include?(hObjData[lErrTypeCtrlId]))
        aInfo[-1] = hObjData["#{sObjType}_enfyinfo1_combo".to_sym()]
      end
      if (hObjData[lErrTypeCtrlId] == "TENFY_SETFLG")
        aInfo.push(hObjData["#{sObjType}_enfyinfo2_entry".to_sym()])
      end
    end

    if (lObjType == :cyclic)
      return "CRE_CYC(#{sObjId}, {#{generate_attribute(:cyclic, hObjData)}, {#{aType.join(' | ')}, #{aInfo.join(', ')}}, #{hObjData[:cyclic_cyctim]}, #{hObjData[:cyclic_cycphs]}});"
    else
      return "CRE_ALM(#{sObjId}, {TA_NULL, {#{aType.join(' | ')}, #{aInfo.join(', ')}}});"
    end
  end
end

SAC_API = {:task => "SAC_TSK",
           :semaphore => "SAC_SEM",
           :eventflag => "SAC_FLG",
           :dataqueue => "SAC_DTQ",
           :pridataq => "SAC_PDQ",
           :mutex => "SAC_MTX",
           :messagebuf => "SAC_MBF",
           :spin_lock => "SAC_SPN",
           :mempfix => "SAC_MPF",
           :cyclic => "SAC_CYC",
           :alarm => "SAC_ALM"}

def generate_sac_api(aConfigData, lObjType, sObjId, hObjData, nTabNum)
  sObjType = lObjType.to_s()
  sApiName = SAC_API[lObjType]
  bIsSet = false
  aAcptnCtrlId = []
  (1..4).each{|nIdx|
    aAcptnCtrlId.push("#{sObjType}_acptn#{nIdx}".to_sym())
    if ((bIsSet == false) && !hObjData[aAcptnCtrlId[-1]].empty?)
      bIsSet = true
    end
  }
  if (bIsSet == true)
    sTab = "\t" * nTabNum
    aAcptn = []
    aAcptnCtrlId.each{|lCtrlId|
      aAcptn.push(hObjData[lCtrlId])
    }
    aConfigData.push("#{sTab}#{sApiName}(#{sObjId}, {#{aAcptn.join(', ')}})")
  end
end



######################################################################
# Open, Save, Print and Output
######################################################################

$sCurrentFile = ""
$hSavedData = {}
def button_open_clicked()
  cDialog = Gtk::FileChooserDialog.new({:title => "Open YAML file", :parent => $hAllCtrl[:window_main], :action => :open, :buttons => [[Gtk::Stock::OPEN, Gtk::ResponseType::ACCEPT], [Gtk::Stock::CANCEL, Gtk::ResponseType::CANCEL]]})
  cDialog.override_font(PANGO_FONT)
  cFilter = Gtk::FileFilter.new()
  cFilter.set_name("*.yaml")
  cFilter.add_pattern("*.yaml")
  cDialog.add_filter(cFilter)
  if (cDialog.run() == Gtk::ResponseType::ACCEPT)
    sTargetFile = cDialog.filename()
    begin
      $hAllConfigData = YAML.load_file(sTargetFile)
      $hSavedData = Marshal.load(Marshal.dump($hAllConfigData))
      if ($hAllConfigData.has_key?(:profile))
        $lCurrentProfile = $hAllConfigData[:profile]
        $hAllCtrl[$lCurrentProfile].set_active(true)
      end

      ALL_OBJ_LABEL.each{|lObjType|
        if (!$hAllConfigData.has_key?(lObjType))
          $hAllConfigData[lObjType] = {}
        end

        lComboCtrlId = "#{lObjType.to_s()}_combo_box".to_sym()
        $hAllCtrl[lComboCtrlId].remove_all()
        sLastId = ""
        $hAllConfigData[lObjType].each{|sObjId, _|
          $hAllCtrl[lComboCtrlId].append_text(sObjId)
          sLastId = sObjId
        }
        if (!$hAllConfigData[lObjType].empty?)
          set_all_obj(lObjType, sLastId)
          $hAllCtrl[lComboCtrlId].set_active($hAllConfigData[lObjType].keys().index(sLastId))
          switch_sensitive_all_obj(lObjType, true)
        else
          switch_sensitive_all_obj(lObjType, false)
        end
      }
    rescue
      message_dialog(:warning, "#{sTargetFile}の読出しに失敗しました")
      $hAllCtrl[:window_main].destroy()
    end
    $sCurrentFile = sTargetFile
    $hAllCtrl[:window_main].set_title(MAIN_TITLE + " (#{$sCurrentFile})")
  end
  cDialog.destroy()

  $cTextView.buffer.set_text(generate_cfg_data())
end

def save_data(sTargetFile)
  $hAllConfigData[:profile] = $lCurrentProfile
  $hSavedData = Marshal.load(Marshal.dump($hAllConfigData))
  open(sTargetFile, "w") do |io|
    YAML.dump($hAllConfigData, io)
  end
end

def button_save_clicked()
  cDialog = Gtk::FileChooserDialog.new({:title => "Save YAML file", :parent => $hAllCtrl[:window_main], :action => :save, :buttons => [[Gtk::Stock::SAVE, Gtk::ResponseType::ACCEPT], [Gtk::Stock::CANCEL, Gtk::ResponseType::CANCEL]]})
  cDialog.override_font(PANGO_FONT)
  cDialog.set_current_name("config.yaml")
  cFilter = Gtk::FileFilter.new()
  cFilter.set_name("*.yaml")
  cFilter.add_pattern("*.yaml")
  cDialog.add_filter(cFilter)
  if (cDialog.run() == Gtk::ResponseType::ACCEPT)
    sTargetFile = cDialog.filename()
    begin
      save_data(sTargetFile)
      message_dialog(:info, "#{sTargetFile}へ保存しました")
    rescue
      message_dialog(:warning, "#{sTargetFile}の保存に失敗しました")
      $hAllCtrl[:window_main].destroy()
    end
    $sCurrentFile = sTargetFile
    $hAllCtrl[:window_main].set_title(MAIN_TITLE + " (#{$sCurrentFile})")
  end
  cDialog.destroy()
end

def button_overwrite_save_clicked()
  if ($sCurrentFile == "")
    button_save_clicked()
    return
  end

  begin
    save_data($sCurrentFile)
  rescue
    message_dialog(:warning, "#{$sCurrentFile}の保存に失敗しました")
    $hAllCtrl[:window_main].destroy()
  end
end

def generate_cfg_data()
  $hAllConfigData.delete(:profile)

  aConfigData = []
  case $lCurrentProfile
  when :asp3
    $hAllConfigData.each{|lObjType, hObjData|
      if ([:messagebuf, :spin_lock].include?(lObjType))
        next
      end
      hObjData.each{|sObjId, _|
        aConfigData.push(generate_cre_api(lObjType, sObjId))
      }
    }

  when :fmp3
    hClass = {}
    $hAllConfigData.each{|lObjType, hObjData|
      if (lObjType == :messagebuf)
        next
      end
      lClassCtrlId = "#{lObjType.to_s()}_class".to_sym()
      hObjData.each{|sObjId, hData|
        if (!hClass.has_key?(hData[lClassCtrlId]))
          hClass[hData[lClassCtrlId]] = {lObjType => []}
        elsif (!hClass[hData[lClassCtrlId]].has_key?(lObjType))
          hClass[hData[lClassCtrlId]][lObjType] = []
        end
        hClass[hData[lClassCtrlId]][lObjType].push(sObjId)
      }
    }

    hClass.each{|sClass, hConfigData|
      aConfigData.push("CLASS(#{sClass}) {")
      hConfigData.each{|lObjType, aObjID|
        aObjID.each{|sObjId|
          aConfigData.push("\t" + generate_cre_api(lObjType, sObjId))
        }
      }
      aConfigData.push("}\n")
    }

  when :hrp3
    hDomain = {}
    aEmptyData = []
    $hAllConfigData.each{|lObjType, hObjData|
      if (lObjType == :spin_lock)
        next
      end
      lDomainCtrlId = "#{lObjType.to_s()}_domain".to_sym()
      hObjData.each{|sObjId, hData|
        if (!hData[lDomainCtrlId].empty?)
          if (!hDomain.has_key?(hData[lDomainCtrlId]))
            hDomain[hData[lDomainCtrlId]] = {lObjType => []}
          elsif (!hDomain[hData[lDomainCtrlId]].has_key?(lObjType))
            hDomain[hData[lDomainCtrlId]][lObjType] = []
          end
          hDomain[hData[lDomainCtrlId]][lObjType].push(sObjId)
        else
          aEmptyData.push([lObjType, sObjId])
        end
      }
    }

    hDomain.each{|sDomain, hConfigData|
      if (sDomain == "KERNEL_DOMAIN")
        aConfigData.push("KERNEL_DOMAIN {")
      else
        aConfigData.push("DOMAIN(#{sDomain}) {")
      end
      hConfigData.each{|lObjType, aObjID|
        aObjID.each{|sObjId|
          aConfigData.push("\t" + generate_cre_api(lObjType, sObjId))
          generate_sac_api(aConfigData, lObjType, sObjId, $hAllConfigData[lObjType][sObjId], 1)
        }
      }
      aConfigData.push("}\n")
    }
    aEmptyData.each{|aData|
      aConfigData.push(generate_cre_api(aData[0], aData[1]))
      generate_sac_api(aConfigData, aData[0], aData[1], $hAllConfigData[aData[0]][aData[1]], 0)
    }

  when :hrmp3
    hClassDomain = {}
    aEmptyData = []
    $hAllConfigData.each{|lObjType, hObjData|
      lClassCtrlId = "#{lObjType.to_s()}_class".to_sym()
      lDomainCtrlId = "#{lObjType.to_s()}_domain".to_sym()
      hObjData.each{|sObjId, hData|
        if (!hData[lDomainCtrlId].empty?)
          if (!hClassDomain.has_key?(hData[lClassCtrlId]))
            hClassDomain[hData[lClassCtrlId]] = {}
          end
          if (!hClassDomain[hData[lClassCtrlId]].has_key?(hData[lDomainCtrlId]))
            hClassDomain[hData[lClassCtrlId]][hData[lDomainCtrlId]] = {lObjType => []}
          elsif (!hClassDomain[hData[lClassCtrlId]][hData[lDomainCtrlId]].has_key?(lObjType))
            hClassDomain[hData[lClassCtrlId]][hData[lDomainCtrlId]][lObjType] = []
          end
          hClassDomain[hData[lClassCtrlId]][hData[lDomainCtrlId]][lObjType].push(sObjId)
        else
          aEmptyData.push([lObjType, sObjId])
        end
      }
    }

    hClassDomain.each{|sClass, hDomainConfigData|
      aConfigData.push("CLASS(#{sClass}) {\n")
      hDomainConfigData.each{|sDomain, hConfigData|
        if (sDomain == "KERNEL_DOMAIN")
          aConfigData.push("\tKERNEL_DOMAIN {")
        else
          aConfigData.push("\tDOMAIN(#{sDomain}) {")
        end
        hConfigData.each{|lObjType, aObjID|
          aObjID.each{|sObjId|
            aConfigData.push("\t\t" + generate_cre_api(lObjType, sObjId))
            generate_sac_api(aConfigData, lObjType, sObjId, $hAllConfigData[lObjType][sObjId], 2)
          }
        }
        aConfigData.push("\t}\n")
      }
      aConfigData.push("}\n")
    }
    aEmptyData.each{|aData|
      aConfigData.push(generate_cre_api(aData[0], aData[1]))
      generate_sac_api(aConfigData, aData[0], aData[1], $hAllConfigData[aData[0]][aData[1]], 0)
    }

  end

  $hAllConfigData[:profile] = $lCurrentProfile
  return(aConfigData.join("\n"))
end

PRINT_WIDTH = 1024
PRINT_HEIGHT = 768
PRINT_MARGIN = 10
$cTextView = Gtk::TextView.new()
$cScrolledWindow = Gtk::ScrolledWindow.new
$cScrolledWindow.set_size_request(PRINT_WIDTH - (PRINT_MARGIN * 2), PRINT_HEIGHT - (PRINT_MARGIN * 2))
$cScrolledWindow.set_margin(PRINT_MARGIN)
$cScrolledWindow.set_policy(:automatic, :automatic)
$cScrolledWindow.add($cTextView)
$cFixed = Gtk::Fixed.new()
$cFixed.put($cScrolledWindow, 0, 0)
$cWindow = Gtk::Window.new()
$cWindow.set_size_request(PRINT_WIDTH, PRINT_HEIGHT)
$cWindow.override_font(Pango::FontDescription.new("MS Gothic 12"))
$cWindow.set_resizable(false)
$cWindow.set_title("View Static API")
$cWindow.add($cFixed)
$cWindow.signal_connect("delete-event") do
  $cWindow.hide()
end

def button_print_clicked()
  $cTextView.buffer.set_text(generate_cfg_data())
  $cWindow.show_all()
end

def button_output_clicked()
  cDialog = Gtk::FileChooserDialog.new({:title => "Save CFG file", :parent => $hAllCtrl[:window_main], :action => :save, :buttons => [[Gtk::Stock::SAVE, Gtk::ResponseType::ACCEPT], [Gtk::Stock::CANCEL, Gtk::ResponseType::CANCEL]]})
  cDialog.override_font(PANGO_FONT)
  cDialog.set_current_name("#{$lCurrentProfile.to_s()}.cfg")
  cFilter = Gtk::FileFilter.new()
  cFilter.set_name("*.cfg")
  cFilter.add_pattern("*.cfg")
  cDialog.add_filter(cFilter)
  if (cDialog.run() == Gtk::ResponseType::ACCEPT)
    sTargetFile = cDialog.filename()
    begin
      File.open(sTargetFile, "w") {|cIO|
        cIO.puts(generate_cfg_data())
      }
      message_dialog(:info, "#{sTargetFile}へ出力しました")
    rescue
      message_dialog(:warning, "#{sTargetFile}の出力に失敗しました")
      $hAllCtrl[:window_main].destroy()
    end
  end
  cDialog.destroy()
end

def window_close()
  if (!$sCurrentFile.empty? && ($hSavedData != $hAllConfigData))
    cDialog = Gtk::MessageDialog.new({:parent => $hAllCtrl[:window_main], :flags => 0, :type => :question, :buttons => :yes_no, :message => "#{$sCurrentFile}に上書き保存しますか？"})
    cDialog.override_font(PANGO_FONT)
    if (cDialog.run() == Gtk::ResponseType::YES)
      begin
        save_data($sCurrentFile)
      rescue
        message_dialog(:warning, "#{$sCurrentFile}の保存に失敗しました")
      end
    end
    cDialog.destroy()
  end
  Gtk.main_quit()
end

def window_destroy()
  Gtk.main_quit()
end

profile_changed()

nfytype_edited($hAllCtrl[:cyclic_nfytype])
$hAllCtrl[:cyclic_button_update].override_color(:normal, COLOR_DEFAULT)
nfytype_edited($hAllCtrl[:alarm_nfytype])
$hAllCtrl[:alarm_button_update].override_color(:normal, COLOR_DEFAULT)

cBuilder.connect_signals{|handler|method(handler)}
$hAllCtrl[:window_main].show()
Gtk.main()
